# -*- coding: utf-8 -*-

'''
Created on Oct 20, 2014

@author: marten
'''

from sqlalchemy.exc import IntegrityError
from decimal import Decimal
from datetime import date
from basesoft.util.virtual_date import set_date
from basesoft.web.core.util.controllers import AbstractController
from basesoft.web.contrib.license.models import Domain, Permission
from basesoft.web.contrib.contact.models import Person
from basesoft.web.contrib.i18n.models import Country
from basesoft.web.contrib.license.controllers import LicenseController
from basesoft.web.contrib.account.models import Account, GroupAccount
from basesoft.web.contrib.account.controllers import AccountController
from sqlalchemy.sql.expression import and_

from django.conf import settings
from we.core.models import WeOperatorLicense
from we.declaration.controllers import WeDeclarationController
from we.member.controllers import WeMemberController

from we.core.sa_datamapper import app_roles
from we.product.controllers import WeProductController
from we.product.models import WeTbsProductLevel
from we.tbs.controllers import WeTbsController
from we.tbs.models import WeTbsLicense


class WeTestController(AbstractController):
    def we_populate(self):
        set_date(date(2015, 8, 8))
        self.domain = self.sa_session.query(Domain).filter(Domain.name == 'WEEE Europe').one()
        self.create_operator()
        self.create_tbses()
        self.create_hqpps()
        self.create_lpps()
        # self.link_cn8_to_weee_category()
        self.add_tbs_product_levels()
        self.add_tbs_regulation_period()
        self.add_hqpp_products()
        self.create_declarations()

    def create_operator(self):

        lc = LicenseController(self.sa_session, account_id=self.get_account().id)
        lc.add_permissions_to_license(self.get_default_group().license, self._get_permissions('we_operator_license', 'manage_roles', 'view_license'))
        lc.add_permissions_to_group(self.get_default_group(), self._get_permissions('we_operator_license', 'manage_roles', 'view_license'))

        _license = self.sa_session.query(WeOperatorLicense).filter(and_(WeOperatorLicense.name=='Operator',
                                                                        WeOperatorLicense.domain==self.domain)).first()

        if _license is None:
            state = self._get_operator_state()
            _license = lc.save_license_from_state(state)

        lc.grant_from_role(lc.get_role_by_name('WE Operator'), _license, _license.default_group)
        if 'we.uat' in settings.INSTALLED_APPS:
            lc.add_permissions_to_license(_license, self._get_permissions('we_user_acceptance_testing', 'user_acceptance_trigger_tasks', 'set_virtual_date'))
            lc.add_permissions_to_group(_license.default_group, self._get_permissions('we_user_acceptance_testing', 'user_acceptance_trigger_tasks', 'set_virtual_date'))

        self._operator_account = self._create_account('we_operator', _license.default_group)
        self._operator_account2 = self._create_account('we_operator2', _license.default_group)

    def _get_permissions(self, *requires):
        return self.sa_session.query(Permission).filter(Permission.name.in_(requires)).all()

    def _get_operator_state(self):
        return {
            'license': {
                'name': u'Operator',
                'expiration_date': None,
                'is_default': True,
                'polymorphic_type': 'WeOperatorLicense',
            },
            'domain': {'name': 'WEEE Europe'},
            'contact_person': {
                'first_name': u'Opera',
                'last_name': u'Tor',
                'gender': Person.MALE,
                'email': u'we-operator@mail-test.basesoft.com',
                'position': u'CEO',
                'phone': '+31206847087',
                'birth_date': '1970-01-01',
                'address_data': self._get_address_data()
            },
            'company': {
                'name': 'Operator Company',
                'vat_no': 'DE 0893.027.827 ',
                'website': u'http://www.basesoft.com',
            },
            'company_address': {
                'address': self._get_address_data(),
                'is_invoice': True,
                'is_delivery': False
            },
            'company_bank_account': {
                'bank_account': {
                    'number': 1234567890,
                    'iban': 'BE35001553652737',
                    'bic': 'GEBEBABB'},
                'is_default': True
            },
            'group': {'name': u'admins'},
            'permissions': [],
            'usage_options': []
        }

    def create_tbses(self):
        states = self._get_tbs_states()
        tc = WeTbsController(self.sa_session, account_id=self._operator_account.id)
        self._tbses = []
        for state in states:
            self._tbses.append(tc.save_tbs(state))

    def create_hqpps(self):
        states = self._get_hqpp_states()
        mc = WeMemberController(self.sa_session, account_id=self._operator_account.id)
        self._hqpps = []
        for state in states:
            self._hqpps.append(mc.save_or_update_member(None, state))

    def create_lpps(self):
        mc = WeMemberController(self.sa_session, account_id=self._operator_account.id)

        state = self._get_lpp_states()
        self._lpps = {}

        for key in state.keys():
            for hqpp in self._hqpps:
                if hqpp.name == key:
                    for lpp in state[key]:
                        lpp['lpp']['member_id'] = hqpp.id
                        for tbs in self._tbses:
                            if tbs.name == lpp['tbs_company_name']:
                                del lpp['tbs_company_name']
                                lpp['lpp']['tbses'][0]['tbs_id'] = tbs.id
                                lpp['lpp']['tbses'][0]['use_as_ar'] = False
				lp = mc.save_or_update_company_details(None, lpp)
                                self._lpps[lp.name] = lp.id
                                break

    def link_cn8_to_weee_category(self):
        pc = WeProductController(self.sa_session, account_id=self._operator_account.id)
        states = self._get_cn8_to_weee_category_states()

        for state in states:
            pc.save_or_update_cn8_weee_product_level(None, state)

    def add_tbs_product_levels(self):
        pc = WeProductController(self.sa_session, account_id=self._operator_account.id)
        self._product_level = self._get_used_tbs_product_levels()
        states = self._get_tbs_product_level_states()
        self._regulation_period_categories = {}

        for state in states:
            # key is = TBS name
            for key in state:

                tbs = [tbs for tbs in self._tbses if tbs.name == key]
                self._regulation_period_categories[key] = []
                # save product level
                for parent in state[key]:
                    level = pc.save_or_update_tbs_product_level(None, parent['label'],
                                                                parent['description'], tbs[0].id,
                                                                invoice_basis=parent['invoice_basis'],
                                                                position=parent['position'])
                    self._regulation_period_categories[key].append({'id': level.id, 'fee': parent['fee']})

                    category = level.label + ' - ' + level.description

                    # get the list with categories for the current tbs
                    for i in xrange(0, len(self._product_level)):
                        used_categories = self._product_level[i]

                        if used_categories.has_key(key):
                            categories = self._product_level[i][key][0]
                            # save the ID of a used product level
                            if categories.has_key(category):
                                self._product_level[i][key][0][category] = level.id

                    # save sublevel
                    for sublevel in parent['sublevels']:
                        s = pc.save_or_update_tbs_product_level(None, sublevel['label'],
                                                                sublevel['description'], tbs[0].id,
                                                                parent_level_id=level.id,
                                                                invoice_basis=sublevel['invoice_basis'],
                                                                position=sublevel['position'])
                        category = s.label + ' - ' + s.description

                        # get the list with categories for the current tbs
                        for i in xrange(0, len(self._product_level)):
                            used_categories = self._product_level[i]

                            if used_categories.has_key(key):
                                categories = self._product_level[i][key][0]
                                # save the ID of a used product level
                                if category in categories.keys():
                                    self._product_level[i][key][0][category] = s.id

                        # create dictionary with category and fee
                        if sublevel.has_key('fee'):
                            self._regulation_period_categories[key].append({'id': s.id, 'fee': sublevel['fee']})
                        else:
                            self._regulation_period_categories[key].append({'id': s.id, 'fee': parent['fee']})

    def add_tbs_regulation_period(self):
        pc = WeProductController(self.sa_session, account_id=self._operator_account.id)
        states = self._get_tbs_product_level_states()
        # loop the regulation periods for each TBS and save
        for state in states:
            for t in state:
                tbs = [tbs for tbs in self._tbses if tbs.name == t].pop()
                rp = pc.save_or_update_regulation_period(None, tbs.id, tbs.name + ' RP',
                                                         2015, 1, 1, self._regulation_period_categories[t])

    def add_hqpp_products(self):
        pc = WeProductController(self.sa_session, account_id=self._operator_account.id)

        states = self._get_hqpp_product_states()

        for state in states:
            # key is = to HQPP name
            for key in state:

                hqpp = [hq for hq in self._hqpps if hq.name == key]
                hqpp = hqpp[0]

                for p in state[key]:
                    p['hqpp_id'] = hqpp.id
                    for l in p['tbs_rowcontrol']:
                        # tbs_id from state is tbs Name so get the ID
                        tbs = self.sa_session.query(WeTbsLicense).filter(WeTbsLicense.name == l['tbs_id']).one()
                        l['tbs_id'] = tbs.id

                        category = l['tbs_product_level_id']

                        # get the list with categories for the current tbs
                        for i in xrange(0, len(self._product_level)):
                            hq = self._product_level[i]
                            if hq.has_key(tbs.name):
                                categories = self._product_level[i][tbs.name][0]
                                # save the ID of a used product level
                                if category in categories.keys():
                                    # set the ID of the category
                                    l['tbs_product_level_id'] = {'all_categories': self._product_level[i][tbs.name][0][category]}

                    product = pc.save_or_update_hqpp_product(None, p)

    def create_declarations(self):
        dc = WeDeclarationController(self.sa_session, account_id=self._operator_account.id)

        states = self._get_declaration_states()
        for state in states:
            state['lpp_id'] = self._lpps[state['lpp_id']]
            dc.save_or_update_declaration(None, state)

    def _create_account(self, name, group):
        a = self.sa_session.query(Account).filter(Account.name == name).first()
        if a is None:
            a = Account()

            a.name = name
            a.person = Person()

        a.password = AccountController(self.sa_session).hash_password('test_password')
        self.sa_session.add(a)

        ga = GroupAccount()
        ga.is_default = True
        ga.active = True
        ga.account = a
        ga.group = group
        self.sa_session.add(ga)
        try:
            self.sa_session.flush()
        except IntegrityError: # we already are at this group :)
            pass
        return a

    def _get_operator_permissions(self):

        permissions = app_roles()[0]['permissions']
        return self._get_permissions(*permissions)

    def _get_address_data(self, country='DE'):
        return {
            'country': self._get_country_id(country)
        }

    def _get_country_id(self, country='DE'):
        return self.sa_session.query(Country).filter(Country.iso_3166_a2 == country).one().id

    def _get_tbs_states(self):
        return [{
            u'contact_person': {u'preferred_locale': 10, u'first_name': u'Michal', u'last_name': u'Mazal', u'middle_name': u'', u'title': u'',
                                u'gender': u'male', u'skype_name': u'', u'fax': u'', u'phone': u'+420 (234) 235 292',
                                u'mobile_phone': u'+420 (725) 054 772', u'birth_date': u'', u'position': u'Manager International Trade',
                                u'department': u'', u'email': u'mazal@asekol.cz'},
            u'company': {u'website': u'http://www.asekol.cz/en/asekol/', u'chamber_of_commerce_nr': None, u'name': u'Asekol a.s.',
                         u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'CZ27373231', u'fr_company_type': None,
                         u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None},
            u'company_bank_account': {u'is_default': True,
                                      u'bank_account': {u'bank_name': u'', u'beneficiary': u'', u'number': u'35-2149920277/0100',
                                                        u'bic': u'KOMBCZPPXXX', u'note': u'', u'iban': u'CZ3501000000352149920277'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Praha 4', u'country': 58, u'state': u'', u'street': u'\u010ceskoslovensk\xe9ho exilu ',
                                              u'postcode': u'143 00 ', u'street_2': u''}}
        }, {
            u'contact_person': {u'preferred_locale': 4, u'first_name': u'Erwan', u'last_name': u'Penlae', u'middle_name': u'', u'title': u'',
                                u'gender': u'male', u'skype_name': u'', u'fax': u'', u'phone': u'+331 (70) 91 63 64', u'mobile_phone': u'',
                                u'birth_date': u'', u'position': u'', u'department': u'', u'email': u'epenlae@eco-systemes.fr'},
            u'company': {u'website': None, u'chamber_of_commerce_nr': None, u'name': u'Eco-Syst\xe8mes', u'it_fiscal_code': None, u'es_cif_nr': None,
                         u'notes': None, u'vat_no': u'FR52347517807', u'fr_company_type': None, u'set_notes': u'', u'fr_naf_code': None,
                         u'fr_rcs_number': None, u'fr_rcs_location': None},
            u'company_bank_account': {u'is_default': True,
                                      u'bank_account': {u'bank_name': u'',
                                                        u'beneficiary': u'',
                                                        u'number': u'',
                                                        u'bic': u'CMCIFR2S',
                                                        u'note': u'',
                                                        u'iban': u'FR7610037332810002652450183'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Paris', u'country': 74, u'state': u'', u'street': u'test', u'postcode': u'1246',
                                              u'street_2': u''}},
        }, {
            u'contact_person': {u'preferred_locale': 52, u'first_name': u'M\xe5rten', u'last_name': u'Sundin', u'middle_name': u'', u'title': u'',
                                u'gender': u'male', u'skype_name': u'', u'fax': u'', u'phone': u'+46 (8) 54521685', u'mobile_phone': u'',
                                u'birth_date': u'', u'position': u'', u'department': u'', u'email': u'marten.sundin@el-kretsen.se'},
            u'company': {u'website': None, u'chamber_of_commerce_nr': None, u'name': u'El Kretsen', u'it_fiscal_code': None, u'es_cif_nr': None,
                         u'notes': None, u'vat_no': u'SE556552748701', u'fr_company_type': None, u'set_notes': u'', u'fr_naf_code': None,
                         u'fr_rcs_number': None, u'fr_rcs_location': None}, u'company_bank_account': {u'is_default': True,
                                                                                                      u'bank_account': {u'bank_name': u'',
                                                                                                                        u'beneficiary': u'',
                                                                                                                        u'number': u'',
                                                                                                                        u'bic': u'HANDSESS',
                                                                                                                        u'note': u'',
                                                                                                                        u'iban': u'SE6360000000000143430688'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Stockholm', u'country': 210, u'state': u'', u'street': u'Klara Norra Kyrkogata 31',
                                              u'postcode': u'11183', u'street_2': u''}},
        }, {
            u'contact_person': {u'preferred_locale': 2, u'first_name': u'Johanna', u'last_name': u'van der Meer-van Hoven', u'middle_name': u'',
                                u'title': u'', u'gender': u'female', u'skype_name': u'', u'fax': u'', u'phone': u'+31 (0)79 7600 610',
                                u'mobile_phone': u'', u'birth_date': u'', u'position': u'', u'department': u'',
                                u'email': u'johanna.vandermeer@wecycle.nl'},
            u'company': {u'website': u'http://www.wecycle.nl/english/corporate/about-wecycle/', u'chamber_of_commerce_nr': None, u'name': u'Wecycle',
                         u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'NL808542928B01', u'fr_company_type': None,
                         u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None},
            u'company_bank_account': {u'is_default': True,
                                      u'bank_account': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'ABNANL2A', u'note': u'',
                                                        u'iban': u'NL09ABNA0529843498'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Zoetermeer ', u'country': 155, u'state': u'', u'street': u'Baron de Coubertinlaan 7',
                                              u'postcode': u'2719 EN', u'street_2': u''}}

        }, {
            u'contact_person': {u'preferred_locale': 3, u'first_name': u'Michaela', u'last_name': u'Gremmer-Scholten', u'middle_name': u'',
                                u'title': u'', u'gender': u'female', u'skype_name': u'', u'fax': u'', u'phone': u'+49 (2203) 8987 - 402',
                                u'mobile_phone': u'', u'birth_date': u'', u'position': u'', u'department': u'',
                                u'email': u'michaela.gremmer-scholten@zentek.de'},
            u'company': {u'website': u'www.zentek.de', u'chamber_of_commerce_nr': None, u'name': u'ZENTEK GmbH & Co KG', u'it_fiscal_code': None,
                         u'es_cif_nr': None, u'notes': None, u'vat_no': u'DE173788828', u'fr_company_type': None, u'set_notes': u'',
                         u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None}, u'company_bank_account': {u'is_default': True,
                                                                                                                            u'bank_account': {
                                                                                                                                u'bank_name': u'',
                                                                                                                                u'beneficiary': u'',
                                                                                                                                u'number': u'',
                                                                                                                                u'bic': u'COBADEFFXXX',
                                                                                                                                u'note': u'',
                                                                                                                                u'iban': u'DE46290400900100660000'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Koeln', u'country': 81, u'state': u'', u'street': u'Ettore-Bugatti-Str. 6-14 ',
                                              u'postcode': u'51149', u'street_2': u''}}
        }, {u'contact_person': {u'preferred_locale': 1, u'first_name': u'Michal', u'last_name': u'Mazal', u'middle_name': u'', u'title': u'',
                                u'gender': u'male', u'skype_name': u'', u'fax': u'', u'phone': u'+420 (234) 235 292', u'mobile_phone': u'',
                                u'department': u'', u'position': u'', u'email': u'mazal@asekol.cz'},
            u'company': {u'website': u'http://www.asekol.sk/asekol/', u'chamber_of_commerce_nr': None, u'name': u'ASEKOL SK s.r.o.',
                         u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'SK2023076594', u'fr_company_type': None,
                         u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None},
            u'company_bank_account': {u'is_default': True,
                                      u'bank_account': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'CEKOSKBX', u'note': u'',
                                                        u'iban': u'SK5075000000000025784753'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Bratislava', u'country': 198, u'state': u'', u'street': u'Lamacska cesta 45',
                                              u'postcode': u'841 03', u'street_2': u''}}
            }, {
            u'contact_person': {u'preferred_locale': 1, u'first_name': u'Fabrizia', u'last_name': u'Gasperini', u'middle_name': u'', u'title': u'',
                                u'gender': u'female', u'skype_name': u'', u'fax': u'', u'phone': u'+39 02 34594629', u'mobile_phone': u'',
                                u'department': u'', u'position': u'', u'email': u'fabrizia.gasperini@consorzioremedia.it'},
            u'company': {u'website': u'http://www.consorzioremedia.it/', u'chamber_of_commerce_nr': None, u'name': u'Consorzio Re.media',
                         u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'IT05053900964', u'fr_company_type': None,
                         u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None},
            u'company_bank_account': {u'is_default': True,
                                      u'bank_account': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'BCITITMM', u'note': u'',
                                                        u'iban': u'IT70G0306901603100000062394'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Milano', u'country': 108, u'state': u'', u'street': u'Via Messina 38',
                                              u'postcode': u'20154', u'street_2': u''}}
        }, {
            u'contact_person': {u'preferred_locale': 1, u'first_name': u'Andrzej', u'last_name': u'Saja', u'middle_name': u'',
                                u'title': u'Dyrektor RTV/IT', u'gender': u'male', u'skype_name': u'', u'fax': u'', u'phone': u'+48 22 4318260',
                                u'mobile_phone': u'', u'department': u'', u'position': u'', u'email': u'Andrzej.Saja@elektroeko.pl'},
            u'company': {u'website': u'http://www.elektroeko.pl/edukacja/120,arty.html', u'chamber_of_commerce_nr': None, u'name': u'ElektroEko SA',
                         u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'PL5272498956', u'fr_company_type': None,
                         u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None},
            u'company_bank_account': {u'is_default': True,
                                      u'bank_account': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'RCBWPLPW', u'note': u'',
                                                        u'iban': u'PL68175000090000000029614814'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'warsaw', u'country': 176, u'state': u'', u'street': u'ul. Hrubieszowska 6a',
                                              u'postcode': u'01-209', u'street_2': u''}}
        }, {
            u'contact_person': {u'preferred_locale': 1, u'first_name': u'Andrea', u'last_name': u'Bastida', u'middle_name': u'', u'title': u'',
                                u'gender': u'female', u'skype_name': u'', u'fax': u'', u'phone': u'+34 (934) 194 048', u'mobile_phone': u'',
                                u'department': u'', u'position': u'', u'email': u'abastida@ecotic.es'},
            u'company': {u'website': u'http://www.ecotic.es/', u'chamber_of_commerce_nr': None, u'name': u'Fundaci\xf3n ECOTIC',
                         u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'ESG63809214', u'fr_company_type': None,
                         u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None},
            u'company_bank_account': {u'is_default': True,
                                      u'bank_account': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'CMCIFR2S', u'note': u'',
                                                        u'iban': u'FR7610037332810002652450183'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Barcelona', u'country': 204, u'state': u'', u'street': u'Avda Diagonal, 467 1\xba-1\xaa',
                                              u'postcode': u'8036', u'street_2': u''}}
        }, {
            u'contact_person': {u'preferred_locale': 1, u'first_name': u'Pasqual', u'last_name': u'Zopp', u'middle_name': u'', u'title': u'',
                                u'gender': u'male', u'skype_name': u'', u'fax': u'', u'phone': u'+41 (43) 2552190', u'mobile_phone': u'',
                                u'department': u'', u'position': u'', u'email': u'pasqual.zopp@sens.ch'},
            u'company': {u'website': u'http://www.erecycling.ch/en', u'chamber_of_commerce_nr': None, u'name': u'Stiftung SENS',
                         u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'EE100428294', u'fr_company_type': None,
                         u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None},
            u'company_bank_account': {u'is_default': True,
                                      u'bank_account': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'KBAGCH22', u'note': u'',
                                                        u'iban': u'CH4700761016013155439'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Zurich', u'country': 211, u'state': u'', u'street': u'Obstgartenstra\xdfe 28',
                                              u'postcode': u'8006', u'street_2': u''}}
        }, {
            u'contact_person': {u'preferred_locale': 1, u'first_name': u'Dennis', u'last_name': u'Lackovic', u'middle_name': u'', u'title': u'',
                                u'gender': u'male', u'skype_name': u'', u'fax': u'', u'phone': u'+41 (444469094) ', u'mobile_phone': u'',
                                u'department': u'', u'position': u'', u'email': u'dennis.lackovic@swicorecycling.ch'},
            u'company': {u'website': u'http://www.swicorecycling.ch/en/home', u'chamber_of_commerce_nr': None, u'name': u'SWICO Recycling',
                         u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'EE100629174', u'fr_company_type': None,
                         u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None},
            u'company_bank_account': {u'is_default': True,
                                      u'bank_account': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'HABAEE2X', u'note': u'',
                                                        u'iban': u'EE112200221014618432'}},
            u'company_address': {u'is_invoice': True, u'is_delivery': True,
                                 u'address': {u'city': u'Zurich', u'country': 211, u'state': u'', u'street': u'Hardturmstrasse 103',
                                              u'postcode': u'8005', u'street_2': u''}}
        }]

    def _get_hqpp_states(self):
        return [
            {u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'CCBPFRPPSTR', u'note': u'',
                            u'iban': u'FR7630004006580001018020219'},
             u'contact_person_data': {u'preferred_locale': 34, u'first_name': u'Gina', u'last_name': u'Killikelly', u'middle_name': u'',
                                      u'title': u'', u'gender': u'female', u'skype_name': u'', u'fax': u'', u'phone': u'123', u'mobile_phone': u'',
                                      u'birth_date': u'', u'position': u'', u'department': u'', u'email': u'c.ludwig@weee-europe.com'},
             u'company': {u'website': None, u'chamber_of_commerce_nr': None, u'name': u'DELL HQ', u'it_fiscal_code': None, u'es_cif_nr': None,
                          u'notes': None, u'vat_no': u'FR06449134733', u'fr_company_type': None, u'set_notes': u'', u'fr_naf_code': None,
                          u'fr_rcs_number': None, u'fr_rcs_location': None},
             u'address_data': {u'city': u'Dublin', u'country': 105, u'state': u'', u'street': u'DELL Street', u'postcode': u'1', u'street_2': u''},
             u'invoice_person_data': {u'preferred_locale': 34, u'first_name': u'DELL Accounting', u'last_name': u'Invoice', u'middle_name': u'',
                                      u'title': u'', u'gender': u'male', u'skype_name': u'', u'is_same_person_as': False, u'fax': u'',
                                      u'phone': u'124', u'mobile_phone': u'', u'birth_date': u'', u'position': u'', u'department': u'',
                                      u'email': u'invoice@test.com'}
             }, {
                u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'COBADEFF', u'note': u'',
                               u'iban': u'DE29384400160775928500'},
                u'contact_person_data': {u'preferred_locale': 2, u'first_name': u'Eelco', u'last_name': u'Smit', u'middle_name': u'', u'title': u'',
                                         u'gender': u'male', u'skype_name': u'', u'fax': u'', u'phone': u'+31 (6319) 55296', u'mobile_phone': u'',
                                         u'birth_date': u'', u'position': u'', u'department': u'', u'email': u'j.vicente@weee-europe.com'},
                u'company': {u'website': u'http://www.philips.com/c/catalog/catalog_selector.jsp', u'chamber_of_commerce_nr': None,
                             u'name': u'Philips Consumer Lifestyle HQ', u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None,
                             u'vat_no': u'HR80258164780', u'fr_company_type': None, u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None,
                             u'fr_rcs_location': None},
                u'address_data': {u'city': u'Amsterdam', u'country': 155, u'state': u'', u'street': u'Philips Center, 6th floor',
                                  u'postcode': u'1096 BC', u'street_2': u'Amstelplein 2'},
                u'invoice_person_data': {u'preferred_locale': 2, u'first_name': u'Eelco', u'last_name': u'Smit', u'middle_name': u'', u'title': u'',
                                         u'gender': u'male', u'skype_name': u'', u'is_same_person_as': True, u'fax': u'',
                                         u'phone': u'+31 (6319) 55296',
                                         u'mobile_phone': u'', u'birth_date': u'', u'position': u'', u'department': u'',
                                         u'email': u'j.vicente@weee-europe.com'}
            }, {
                u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'HABAEE2X', u'note': u'',
                               u'iban': u'EE112200221014618432'},
                u'contact_person_data': {u'preferred_locale': 1, u'first_name': u'David', u'last_name': u'Scuderi', u'middle_name': u'',
                                         u'title': u'',
                                         u'gender': u'male', u'skype_name': u'', u'fax': u'', u'phone': u'+44 (0) 1932 455 667', u'mobile_phone': u'',
                                         u'birth_date': u'', u'position': u'', u'department': u'', u'email': u'j.vicente@weee-europe.com'},
                u'company': {u'website': u'www.samsung.com', u'chamber_of_commerce_nr': None, u'name': u'Samsung Electronics Europe',
                             u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'GB208035440', u'fr_company_type': None,
                             u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None},
                u'address_data': {u'city': u'Chertsey', u'country': 230, u'state': u'Surrey', u'street': u'Samsung House', u'postcode': u'KT16 0PS',
                                  u'street_2': u'1000 Hillswood Drive'},
                u'invoice_person_data': {u'preferred_locale': 1, u'first_name': u'David', u'last_name': u'Scuderi', u'middle_name': u'',
                                         u'title': u'',
                                         u'gender': u'male', u'skype_name': u'', u'is_same_person_as': True, u'fax': u'',
                                         u'phone': u'+44 (0) 1932 455 667', u'mobile_phone': u'', u'birth_date': u'', u'position': u'',
                                         u'department': u'', u'email': u'j.vicente@weee-europe.com'}}
        ]

    def _get_lpp_states(self):
        return {
            'DELL HQ': [
                {
                    u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                    u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                             u'gender': None, u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                             u'birth_date': u'', u'position': u'', u'department': u'', u'email': u''},
                    u'address_data': {u'city': u'', u'country': 74, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                      u'street_2': u''},
                    u'website': None, u'chamber_of_commerce_nr': None, u'name': u'DELL France', u'it_fiscal_code': None,
                    u'es_cif_nr': None, u'notes': None, u'vat_no': u'ESB45586724', u'fr_company_type': None, u'set_notes': u'',
                    u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                    u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                         u'use_as_ar': False}], u'member_id': 14},
                    u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'Eco-Systèmes'
                },
                {
                    u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                    u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                             u'gender': None, u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                             u'birth_date': u'', u'position': u'', u'department': u'', u'email': u''},
                    u'address_data': {u'city': u'', u'country': 81, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                      u'street_2': u''},
                    u'website': None, u'chamber_of_commerce_nr': None, u'name': u'DELL Germany', u'it_fiscal_code': None,
                    u'es_cif_nr': None, u'notes': None, u'vat_no': u'IT02426720427', u'fr_company_type': None, u'set_notes': u'',
                    u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                    u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                         u'use_as_ar': False}], u'member_id': 14},
                    u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'ZENTEK GmbH & Co KG'
                },
                {
                    u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                    u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                             u'gender': None, u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                             u'birth_date': u'', u'position': u'', u'department': u'', u'email': u''},
                    u'address_data': {u'city': u'', u'country': 210, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                      u'street_2': u''},
                    u'website': None, u'chamber_of_commerce_nr': None, u'name': u'DELL Sweden', u'it_fiscal_code': None,
                    u'es_cif_nr': None, u'notes': None, u'vat_no': u'IT08219930156', u'fr_company_type': None, u'set_notes': u'',
                    u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                    u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                         u'use_as_ar': False}], u'member_id': 14},
                    u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'El Kretsen'
                }
            ],
            'Philips Consumer Lifestyle HQ': [
                {u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                 u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                          u'gender': u'', u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                          u'birth_date': u'', u'position': u'', u'department': u'', u'email': u''},
                 u'address_data': {u'city': u'', u'country': 155, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                   u'street_2': u''},
                 u'website': None, u'chamber_of_commerce_nr': None, u'name': u'Philips Consumer Lifestyle NL',
                 u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'IT02316880216', u'fr_company_type': None,
                 u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                 u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                      u'use_as_ar': False}], u'member_id': 16},
                 u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'Wecycle'},

                {u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                 u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                          u'gender': u'', u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                          u'birth_date': u'', u'position': u'', u'department': u'', u'email': u''},
                 u'address_data': {u'city': u'', u'country': 74, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                   u'street_2': u''},
                 u'website': None, u'chamber_of_commerce_nr': None, u'name': u'Philips Consumer Lifestyle FR',
                 u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'FR32412015299', u'fr_company_type': None,
                 u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                 u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                      u'use_as_ar': False}], u'member_id': 16},
                 u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'Eco-Systèmes'},

                {u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                 u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                          u'gender': u'', u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                          u'birth_date': u'', u'position': u'', u'department': u'', u'email': u''},
                 u'address_data': {u'city': u'', u'country': 155, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                   u'street_2': u''},
                 u'website': None, u'chamber_of_commerce_nr': None, u'name': u'Philips Netherlands', u'it_fiscal_code': None,
                 u'es_cif_nr': None, u'notes': None, u'vat_no': u'FR13519040760', u'fr_company_type': None, u'set_notes': u'',
                 u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                 u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                      u'use_as_ar': False}], u'member_id': 16},
                 u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'Wecycle'}
            ],
            'Samsung Electronics Europe': [
                {
                    u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                    u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                             u'gender': u'', u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                             u'birth_date': u'', u'position': u'', u'department': u'', u'email': u''},
                    u'address_data': {u'city': u'', u'country': 155, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                      u'street_2': u''},
                    u'website': None, u'chamber_of_commerce_nr': None, u'name': u'Samsung Benelux BV', u'it_fiscal_code': None,
                    u'es_cif_nr': None, u'notes': None, u'vat_no': u'IE4739602K', u'fr_company_type': None, u'set_notes': u'',
                    u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                    u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                         u'use_as_ar': False}], u'member_id': 18},
                    u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'Wecycle'
                },
                {
                    u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                    u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                             u'gender': None, u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                             u'department': u'',
                                             u'position': u'', u'email': u''},
                    u'address_data': {u'city': u'', u'country': 204, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                      u'street_2': u''},
                    u'website': None, u'chamber_of_commerce_nr': None, u'name': u'Samsung Iberia SA', u'it_fiscal_code': None,
                    u'es_cif_nr': None, u'notes': None, u'vat_no': u'ESA14219836', u'fr_company_type': None, u'set_notes': u'',
                    u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                    u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                         u'use_as_ar': False}], u'member_id': 18},
                    u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'Fundación ECOTIC'
                },
                {
                    u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                    u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                             u'gender': None, u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                             u'department': u'',
                                             u'position': u'', u'email': u''},
                    u'address_data': {u'city': u'', u'country': 176, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                      u'street_2': u''},
                    u'website': None, u'chamber_of_commerce_nr': None, u'name': u'Samsung Polska', u'it_fiscal_code': None,
                    u'es_cif_nr': None, u'notes': None, u'vat_no': u'PL7640001443', u'fr_company_type': None, u'set_notes': u'',
                    u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                    u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                         u'use_as_ar': False}], u'member_id': 18},
                    u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'ElektroEko SA'
                },
                {
                    u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                    u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                             u'gender': None, u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                             u'department': u'',
                                             u'position': u'', u'email': u''},
                    u'address_data': {u'city': u'', u'country': 108, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                      u'street_2': u''},
                    u'website': None, u'chamber_of_commerce_nr': None, u'name': u'Samsung Electronics Italia SPA',
                    u'it_fiscal_code': None,
                    u'es_cif_nr': None, u'notes': None, u'vat_no': u'IT12036460157', u'fr_company_type': None, u'set_notes': u'',
                    u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                    u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                         u'use_as_ar': False}], u'member_id': 18},
                    u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'Consorzio Re.media'
                },
                {
                    u'bank_data': {u'bank_name': u'', u'beneficiary': u'', u'number': u'', u'bic': u'', u'note': u'', u'iban': u''},
                    u'contact_person_data': {u'preferred_locale': u'', u'first_name': u'', u'last_name': u'', u'middle_name': u'', u'title': u'',
                                             u'gender': None, u'skype_name': u'', u'fax': u'', u'phone': u'', u'mobile_phone': u'',
                                             u'department': u'',
                                             u'position': u'', u'email': u''},
                    u'address_data': {u'city': u'', u'country': 211, u'state': u'', u'street': u'', u'postcode': u'', u'dbID': None,
                                      u'street_2': u''},
                    u'website': None, u'chamber_of_commerce_nr': None, u'name': u'Samsung Electronics Switzerland GmbH ',
                    u'it_fiscal_code': None, u'es_cif_nr': None, u'notes': None, u'vat_no': u'ATU64890559', u'fr_company_type': None,
                    u'set_notes': u'', u'fr_naf_code': None, u'fr_rcs_number': None, u'fr_rcs_location': None,
                    u'lpp': {u'tbses': [{u'tbs_id': None, u'lpp_relation_id': None, u'invoice_relation_id': None, u'lpp_id': None,
                                         u'use_as_ar': False}], u'member_id': 18},
                    u'tbs_links': [{u'tbs_id': None, u'lpp_id': None, u'ar_company_id': None, u'invoice_company_id': None}], u'tbs_company_name': u'SWICO Recycling'
                }
            ]
        }

    def _get_cn8_to_weee_category_states(self):
        return [{u'unu_code': 7, u'weee_product_level_id': 4, u'cn8_codes': [84181020, 84181080]},
                {u'unu_code': 4, u'weee_product_level_id': 7, u'cn8_codes': [84501190]},
                {u'unu_code': 9, u'weee_product_level_id': 19, u'cn8_codes': [84151090, 84158100]},
                {u'unu_code': 16, u'weee_product_level_id': 22, u'cn8_codes': [85081900]},
                {u'unu_code': 13, u'weee_product_level_id': 26, u'cn8_codes': [85164000]},
                {u'unu_code': 17, u'weee_product_level_id': 31, u'cn8_codes': [85101000]},
                {u'unu_code': 20, u'weee_product_level_id': 39, u'cn8_codes': [84713000]},
                {u'unu_code': 21, u'weee_product_level_id': 37, u'cn8_codes': [84433180]},
                {u'unu_code': 26, u'weee_product_level_id': 38, u'cn8_codes': [85285980]},
                {u'unu_code': 30, u'weee_product_level_id': 64, u'cn8_codes': [85286100]},
                {u'unu_code': 32, u'weee_product_level_id': 59, u'cn8_codes': [85258030]},
                {u'unu_code': 34, u'weee_product_level_id': 58, u'cn8_codes': [85287240]}
        ]

    def _get_tbs_product_level_states(self):
        return [
            {
                u'Eco-Systèmes': [
                    {
                        'label': '1',
                        'description': 'Large Household Appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'position': 1,
                        'fee': Decimal('0.08000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '11010',
                                'description': 'Refrigerator Freezer > 40 kg Refrigerant with GWP <= 15',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                            }, {
                                'label': '11011',
                                'description': 'Refrigerator Freezer > 40 kg Refrigerant with GWP > 15',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                            }, {
                                'label': '11020',
                                'description': 'Refrigerator Freezer <= 40 kg Refrigerant with GWP <= 15',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                            }, {
                                'label': '11021',
                                'description': 'Refrigerator Freezer <= 40 kg Refrigerant with GWP > 15',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                            }, {
                                'label': '11030',
                                'description': 'Large Cooling Appliance > 40 kg Refrigerant with GWP <= 15',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 5,
                            }, {
                                'label': '11032',
                                'description': 'Large Cooling Appliance > 40 kg Refrigerant with GWP > 15',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 6,
                            }
                        ]
                    }, {
                        'label': '2',
                        'description': 'Small Household Appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'position': 2,
                        'fee': Decimal('0.2000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '25010',
                                'description': 'Refrigerator Freezer <= 40 kg Refrigerant with GWP > 15 25010. Vacuum cleaner without plastic parts > 25 grams containing brominated flame retardants',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                            }, {
                                'label': '25011',
                                'description': 'Vacuum cleaner with plastic parts > 25 grams containing brominated flame retardants',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                            }, {
                                'label': '25020',
                                'description': 'SHA (excluding Vacuum cleaner)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                            }, {
                                'label': '25040',
                                'description': 'Small SHA',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                            }, {
                                'label': '25050',
                                'description': 'Very Small SHA',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 5
                            }
                        ]
                    }, {
                        'label': '3',
                        'description': 'IT and telecommunications equipement',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'position': 3,
                        'fee': Decimal('0.15000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '32010',
                                'description': 'VERY LARGE MONITOR > 25 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                            }, {
                                'label': '32020',
                                'description': 'LARGE MONITOR > 13 kg et <= 25 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                            }, {
                                'label': '32030',
                                'description': 'MEDIUM-SIZED MONITOR >7 kg et <=13 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                            }, {
                                'label': '32040',
                                'description': 'SMALL MONITOR <=7 kg et >= 7',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                            }, {
                                'label': '32052',
                                'description': 'Laptop Computer Without mercury-containing lighting',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 5,
                            }, {
                                'label': '36040',
                                'description': 'Small IT Equipment <7',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 6,
                            }
                        ]
                    }, {
                        'label': '4',
                        'description': 'Consumer Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'position': 4,
                        'fee': Decimal('0.30000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '45010',
                                'description': 'LARGE CONSUMER EQUIPMENT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                            }, {
                                'label': '45030',
                                'description': 'SMALL CONSUMER EQUIPMENT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                            }
                        ]
                    }, {
                        'label': '6',
                        'description': 'Tools',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.77000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 5,
                        'sublevels': []
                    }
                ]
            }, {
                'El Kretsen': [
                    {
                        'label': '3',
                        'description': 'IT and telecommunications equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'position': 1,
                        'fee': Decimal('0.21000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '3.1',
                                'description': 'MFP (multifunction products)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                            }, {
                                'label': '3.2',
                                'description': 'Computers',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                            }, {
                                'label': '3.3.1',
                                'description': 'Monitors up to 19 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                            }, {
                                'label': '3.3.2',
                                'description': 'Monitors 19–25 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                            }, {
                                'label': '3.3.3',
                                'description': 'Monitors 26–31inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 5,
                            }, {
                                'label': '3.3.4',
                                'description': 'Monitors 32–36 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 6,
                            }, {
                                'label': '3.3.5',
                                'description': 'Monitors 37–47 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 7,
                            }, {
                                'label': '3.3.6',
                                'description': 'Monitors larger than 48 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 8,
                            }, {
                                'label': '3.4',
                                'description': 'Other ICT products',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 9,
                            }, {
                                'label': '3.5',
                                'description': 'Telecom-products',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 10,
                            }
                        ]
                    }, {
                        'label': '4',
                        'description': 'Consumer Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'position': 2,
                        'fee': Decimal('0.03000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '4.1.1',
                                'description': 'TV-sets up to 19 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                            }, {
                                'label': '4.1.2',
                                'description': 'TV-sets 19–25 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                            }, {
                                'label': '4.1.3',
                                'description': 'TV-sets 26–31inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                            }, {
                                'label': '4.1.4',
                                'description': 'TV-sets 32–36 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                            }, {
                                'label': '4.1.5',
                                'description': 'TV-sets 37–47 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 5,
                            }, {
                                'label': '4.1.6',
                                'description': 'TV-sets lager than 48 inches',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 6,
                            }, {
                                'label': '4.2',
                                'description': 'Stationary consumer equipment',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 7,
                            }, {
                                'label': '4.3',
                                'description': 'Portable consumer equipment',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 8,
                            }
                        ]
                    }
                ]
            }, {
                'Wecycle': [
                    {
                        'label': '1.',
                        'description': 'Large Household Appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'position': 1,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '1/C01',
                                'description': 'Extraction hood',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.06500'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1/C02',
                                'description': 'Air conditioner (separate)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('0.77000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1/C14',
                                'description': 'Washing machine',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('0.13000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1/C16',
                                'description': 'Fridge',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                                'fee': Decimal('0.77000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1/P50',
                                'description': 'Air conditioner (professional/built-in) < 1kg coolant',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 5,
                                'fee': Decimal('0.08000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '2.',
                        'description': 'Small Household Appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'position': 2,
                        'fee': Decimal('0.16000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '2/C01',
                                'description': 'Fryer',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2/C02',
                                'description': 'Household appliance (small)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2/C03',
                                'description': 'Coffee/espresso machine',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2/C04',
                                'description': 'Personal care appliance',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 4,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2/C05',
                                'description': 'Vacuum/floor cleaner',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 5,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2/C06',
                                'description': 'Fabric processing appliance',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 6,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '3.',
                        'description': 'IT and Telecommunication Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'position': 3,
                        'fee': Decimal('0.20000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '3/C05',
                                'description': 'Mobile/smartphone',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.06000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3/C08',
                                'description': 'Printer/scanner',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.06000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3/C10',
                                'description': 'IT-/office appliance (small)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.06000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3/C06',
                                'description': 'Monitor (flatscreen)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 4,
                                'fee': Decimal('0.07900'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '4.',
                        'description': 'Consumer appliances Image & Sound',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'position': 4,
                        'fee': Decimal('0.04000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '4/C01',
                                'description': 'Audio/video appliance (portable)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.01000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '4/C02',
                                'description': 'Audio/video appliance (not portable)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.01000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '4/C03',
                                'description': 'TV/display (flatscreen)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.01800'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '5.',
                        'description': 'IT and Telecommunication Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'position': 5,
                        'fee': Decimal('0.13000'),
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '5/P54',
                                'description': 'Led lamp (plug-in)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.14000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }
                ]
            }, {
                u'ZENTEK GmbH & Co KG': [
                    {
                        'label': '3',
                        'description': 'IT and Telecommunications Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.15000'),
                        'position': 1,
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '3.1',
                                'description': "'Personal' information and/or data processing",
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                            }, {
                                'label': '3.2',
                                'description': "'Personal' printing of information and transmission of printed information",
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                            }, {
                                'label': '3.3',
                                'description': "'Personal' telecommunications equipment",
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                            }, {
                                'label': '3.4',
                                'description': 'Mobile phones',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 4,
                            }, {
                                'label': '3.5',
                                'description': 'Data viewing devices',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 5,
                            }, {
                                'label': '3.6',
                                'description': 'Cameras (photo)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 6,
                            }, {
                                'label': '3.7',
                                'description': "'Professional' equipment",
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 7,
                                'fee': Decimal('0.30000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '4',
                        'description': 'Consumer Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.50000'),
                        'position': 2,
                        'fee_date': date(2015, 1, 1),
                        'sublevels': [
                            {
                                'label': '4.1',
                                'description': 'TV Sets',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                            }, {
                                'label': '4.2',
                                'description': 'Other consumer equipment (except television sets)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                            }, {
                                'label': '4.3',
                                'description': "'Professional' audio and video equipment, 'Professional' large display units",
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.80000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }
                ]
            }, {
                u'ASEKOL SK s.r.o.': [
                    {
                        'label': '1.',
                        'description': 'Large household appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 1,
                        'sublevels': [
                            {
                                'label': '1.2.1.2.',
                                'description': 'Refrigerators - 45 kg - 100 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('16.52000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1.5.1.2.',
                                'description': 'Washing machines - above 30 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('4.51000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1.17.1.1.',
                                'description': 'Air conditioning appliances - with cooling filling',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('4.51000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '2.',
                        'description': 'Small household appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 2,
                        'sublevels': [
                            {
                                'label': '2.1.1.',
                                'description': 'Vacuum cleaners - above 2 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.27000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2.5.1.',
                                'description': 'Irons and other appliances for ironing, mangling and other care of clothing',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('0.13500'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '3.',
                        'description': 'IT and telecommunications equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 3,
                        'sublevels': [
                            {
                                'label': '3.4.5.',
                                'description': 'Screens - LED with a diagonal to 25"',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.19000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3.9.1.1.',
                                'description': 'Copymachines and multifunctional equipment - up to 50 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('0.14000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3.19.1.',
                                'description': 'Cellular telephones',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('0.14000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '4.',
                        'description': 'Consumer Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 4,
                        'sublevels': [
                            {
                                'label': '4.2.2.3.',
                                'description': 'LED Television sets - up to 25" diagonal',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.23500'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '4.3.1.1.',
                                'description': 'Videocameras - Consumer cameras',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('0.13000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '5.',
                        'description': 'Consumer Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 5,
                        'sublevels': [
                            {
                                'label': '5.1.',
                                'description': 'Linear fluorescent lamps',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.30000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '5.2.',
                                'description': 'Compact fluorescent lamps',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('0.30000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }
                ]
            }, {
                u'Asekol a.s.': [
                    {
                        'label': '1.',
                        'description': 'Large household appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 1,
                        'sublevels': [
                            {
                                'label': '1.2.1.',
                                'description': 'Refrigerators, combination of refrigerator and freezer-over 40 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.00000'),
                                'fee_date': date(2015, 4, 1),
                            }, {
                                'label': '1.5.1.',
                                'description': 'Washing machines - over 30 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('12.26000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1.17.1.',
                                'description': 'Air conditioning appliances - with refrigerants',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('54.15000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '2.',
                        'description': 'Small household appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 2,
                        'sublevels': [
                            {
                                'label': '2.1.1.',
                                'description': 'Vacuum cleaners - over 2 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('12.26000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2.5.',
                                'description': 'Irons and other appliances for ironing, mangling and other care of clothing',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('2.76500'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '3.',
                        'description': 'IT and telecommunications equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 3,
                        'sublevels': [
                            {
                                'label': '3.4.3.7.',
                                'description': 'Screens -LED up to 25" diagonal',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('41.60000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3.9.1.1.',
                                'description': 'Copymachines and multifunctional equipment',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('12.60000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3.19.1.',
                                'description': 'Mobile telephones',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('1.26000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '4.',
                        'description': 'Consumer Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 4,
                        'sublevels': [
                            {
                                'label': '4.2.2.3.',
                                'description': 'LCD/LED Television sets - up to 25" diagonal',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('416.00000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '4.3.1.1.',
                                'description': 'Videocameras - Consumer cameras',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('8.40000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '5.',
                        'description': 'Lighting Equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 5,
                        'sublevels': [
                            {
                                'label': '5.1.',
                                'description': 'Linear fluorescent lamps',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('7.00000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '5.2.',
                                'description': 'Compact fluorescent lamps',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('2.00000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }
                ]
            }, {
                u'Consorzio Re.media': [
                    {
                        'label': '5.',
                        'description': 'LIGHTING EQUIPMENT',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 5,
                        'sublevels': [
                            {
                                'label': '5.2.1',
                                'description': 'Fluorescent tubes_INT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.25900'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '5.3.1',
                                'description': 'Compact fluorescent lamps_INT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.25900'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '3.',
                        'description': 'IT AND TELECOMMUNICATIONS EQUIPMENT',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 3,
                        'sublevels': [
                            {
                                'label': '3.2.5',
                                'description': 'Printers',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3.2.15',
                                'description': 'Cellular telephones',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3.2.9',
                                'description': 'User terminals and systems (monitors)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.38400'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '4.',
                        'description': 'CONSUMER EQUIPMENT AND PHOTOVOLTAIC PANELS',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 4,
                        'sublevels': [
                            {
                                'label': '4.2.3',
                                'description': 'Television sets >15" <=32"_ECR',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('3.31000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '4.3.1',
                                'description': 'Video cameras_INT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '1.',
                        'description': 'LARGE HOUSEHOLD APPLIANCES',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 1,
                        'sublevels': [
                            {
                                'label': '1.1.1',
                                'description': 'Large cooling appliances_INT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.09800'),
                                'fee_date': date(2015, 4, 1),
                            }, {
                                'label': '1.5.1',
                                'description': 'Washing machines_INT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.02100'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1.17.1',
                                'description': 'Air conditioning appliances_INT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.06700'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '2.',
                        'description': 'SMALL HOUSEHOLD APPLIANCES',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 2,
                        'sublevels': [
                            {
                                'label': '2.1.1',
                                'description': 'Vacuum cleaners_INT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2.5.1',
                                'description': 'Vacuum cleaners_INT',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2.11',
                                'description': 'Clocks, watches, and equipment for the purpose of measuring or registering time',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.02700'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }
                ]
            }, {
                u'ElektroEko SA': [
                    {
                        'label': '5.',
                        'description': 'Lighting equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 5,
                        'sublevels': [
                            {
                                'label': '5.2.1.',
                                'description': 'Straight fluorescent lamps',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.40000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '5.3.1.',
                                'description': 'Compact fluorescent lamps',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.20000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '3.',
                        'description': 'IT and telecommunications equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 3,
                        'sublevels': [
                            {
                                'label': '3B.1.2.',
                                'description': 'Monitors/Screen',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.11400'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3B.5.',
                                'description': 'Printers',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.11400'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '3B.16.',
                                'description': 'Cellular telephones',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.11400'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '4.',
                        'description': 'Consumer equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 4,
                        'sublevels': [
                            {
                                'label': '4.2.',
                                'description': 'Television sets',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.12900'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '4.3.',
                                'description': 'Videocameras',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.12900'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '1.',
                        'description': 'Large household appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 1,
                        'sublevels': [
                            {
                                'label': '1.2.',
                                'description': 'Refrigerators',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.13600'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1.5a.',
                                'description': 'Washing machines',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.13600'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1.17.',
                                'description': 'Air conditioner appliances',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.13600'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '2.',
                        'description': 'Small household appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 2,
                        'sublevels': [
                            {
                                'label': '2.1.',
                                'description': 'Vacuum cleaners',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.12100'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2.5.',
                                'description': 'Irons and other appliances for ironing, mangling and other care of clothing',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.12100'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '2.11.',
                                'description': 'Clocks, watches and equipment for the purpose of measuring, indicating or registering time',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.12100'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }
                ]
            }, {
                u'Fundación ECOTIC': [
                    {
                        'label': '5.',
                        'description': 'Lighting equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 5,
                        'sublevels': [
                            {
                                'label': '60',
                                'description': 'FLUORESCENT TUBES',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.30000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '61',
                                'description': 'COMPACT FLUORESCENT LAMPS',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('0.20000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '3.',
                        'description': 'IT and telecommunications equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 3,
                        'sublevels': [
                            {
                                'label': '158',
                                'description': 'Cell phones',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.07000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '144-1',
                                'description': 'Screens (MONITORS)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.26000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '147',
                                'description': 'Printers',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.07000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '4.',
                        'description': 'Consumer equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 4,
                        'sublevels': [
                            {
                                'label': '161-32',
                                'description': 'VIDEO/PHOTO CAMERA',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.07000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '162-14',
                                'description': 'TV LCD 21-23"',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.26000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '503',
                                'description': 'HOTEL TV (used in hotels)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.18500'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '1.',
                        'description': 'Large household appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 1,
                        'sublevels': [
                            {
                                'label': '112',
                                'description': 'REFRIGERATOR AND FREEZERr > =45 < 70 KG',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.12000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '115',
                                'description': 'WASHING MACHINE',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.02300'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '127-1',
                                'description': 'AIR CONDITIONING APPLIANCES (split)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 3,
                                'fee': Decimal('0.01900'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': '2.',
                        'description': 'Small household appliances',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 2,
                        'sublevels': [
                            {
                                'label': '133',
                                'description': 'IRONING MACHINE',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 1,
                                'fee': Decimal('0.06000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '139',
                                'description': 'TIME CLOCKS',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT,
                                'position': 2,
                                'fee': Decimal('0.06000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }
                ]
            }, {
                u'SWICO Recycling': [
                    {
                        'label': 'Office/IT',
                        'description': 'Office/IT',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 1,
                        'sublevels': [
                            {
                                'label': '1000050',
                                'description': 'Mouse, PC keyboard, Hard Disk, Switchbox, Scanner Pen, Main Adaptor (AC/DC)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.37000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1000040',
                                'description': 'Monitor/all-in-one-PC up to14", Notebook/laptop (up to 11.9"), Docking Station (Laptops), Scanner from A4',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('1.85000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1000070',
                                'description': 'Printer',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('3.70000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1000030',
                                'description': 'Monitor/All-in-One_PC from 15" (36cm), Notebook/Tablet/Laptop (from 12"), PC, Projector',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                                'fee': Decimal('5.55000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1000020',
                                'description': 'Monitor/All-in-One-PC from 33" (83cm)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 5,
                                'fee': Decimal('11.11000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1000010',
                                'description': 'Monitor/All-in-One-PC from 45" (114cm)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 6,
                                'fee': Decimal('16.67000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '1000005',
                                'description': 'Monitor/All-in-One-PC from 70" (177cm) screen diagonal',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 7,
                                'fee': Decimal('25.93000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': 'Consumer Electronics',
                        'description': 'Consumer Electronics',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 2,
                        'sublevels': [
                            {
                                'label': 'I2000007',
                                'description': 'Headphones InEar, MP3/4, AAC, WAV, WMA (DRM) Player, GPS aid to location',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.09000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': 'H2000050',
                                'description': 'Remote control, Headphones OnEar, Portable game consoles (PSP, etc), 3D glasses',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('0.37000'),
                                'fee_date': date(2015, 1, 1)
                            }, {
                                'label': 'F2000200',
                                'description': 'CD/DVD/Blu-Ray Recorder/Player, Mini-Midi system, Stationary game console (X-box, PS, etc)',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('1.85000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': 'C2000700',
                                'description': 'Television from 15" (36cm) screen diagonal, Video projector',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                                'fee': Decimal('5.55000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': 'B2001400',
                                'description': 'Television from 33" (83cm) screen diagonal',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 5,
                                'fee': Decimal('11.11000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': 'A2002000',
                                'description': 'Television from 45" (114cm) screen diagonal',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 6,
                                'fee': Decimal('16.67000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': 'A2002800',
                                'description': 'Television from 70" (177cm) screen diagonal',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 7,
                                'fee': Decimal('25.93000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': 'Telecommunications',
                        'description': 'Telecommunications',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 3,
                        'sublevels': [
                            {
                                'label': '3000000',
                                'description': 'Mobile phones/smart watch, Accessories for mobile phones, Walky-Talky',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.09000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '4000010',
                                'description': 'Telephone equipment (standard, cordless telephones, ISDN etc.), Modem',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('0.37000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }
                ]
            }, {
                u'Stiftung SENS': [
                    {
                        'label': 'SENS Equipment',
                        'description': 'General Household and Kitchen Equipment, washing and drying, cooking and baking, garden and proprety managment equipment',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 1,
                        'sublevels': [
                            {
                                'label': '100110',
                                'description': '5 < 15 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.37000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '100120',
                                'description': '15 < 25 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('5.56000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '100210',
                                'description': '70 < 140 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('18.52000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '100090',
                                'description': '< 0.250 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                                'fee': Decimal('0.18500'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '100100',
                                'description': '< 5kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 5,
                                'fee': Decimal('0.56000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '100200',
                                'description': '25 < 75 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 6,
                                'fee': Decimal('11.11000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': 'Refrigeration, Freezing and Room-Air Treatment Units with Compressors',
                        'description': 'Air-conditioning units, coolers, refrigerators, food centres, freezer appliances, chilled drinks dispensers',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 2,
                        'sublevels': [
                            {
                                'label': '100300',
                                'description': '< 25 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('9.26000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '100310',
                                'description': '25 < 100 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('27.78000'),
                                'fee_date': date(2015, 1, 1)
                            }, {
                                'label': '100320',
                                'description': '100 < 250 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('46.30000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '100330',
                                'description': '≥ 250 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 4,
                                'fee': Decimal('55.56000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }, {
                        'label': 'Power Tools, torches and photovoltaic modules',
                        'description': 'Drilling, milling, riveting, welding, nailing, sawing, polishing, griding, handheld meters',
                        'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                        'fee': Decimal('0.00000'),
                        'fee_date': date(2015, 1, 1),
                        'position': 3,
                        'sublevels': [
                            {
                                'label': '310090',
                                'description': '< 0,25 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 1,
                                'fee': Decimal('0.79000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '310095',
                                'description': '< 2kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 2,
                                'fee': Decimal('2.36000'),
                                'fee_date': date(2015, 1, 1),
                            }, {
                                'label': '310100',
                                'description': '< 5 kg',
                                'invoice_basis': WeTbsProductLevel.INVOICE_BASED_ON_QUANTITY,
                                'position': 3,
                                'fee': Decimal('3.75000'),
                                'fee_date': date(2015, 1, 1),
                            }
                        ]
                    }
                ]
            }
        ]

    def _get_hqpp_product_states(self):
        return [
            {
                'DELL HQ': [
                    {
                        u'sku': u'210-34498', u'diagonal': Decimal('1000.00'), u'length_per_unit': None, u'hqpp_id': 15, u'sales_price': None,
                        u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                        u'weight_per_unit': Decimal('1.320'), u'weight_cat4': None, u'height_per_unit': Decimal('999.999'), u'width_per_unit': None,
                        u'tbs_rowcontrol': [
                            {u'tbs_product_level_id': '36040 - Small IT Equipment <7', u'tbs_id': u'Eco-Syst\xe8mes',
                             u'hqpp_period_product_id': None, u'is_b2b': None},
                            {u'tbs_product_level_id': "3.1 - 'Personal' information and/or data processing", u'tbs_id': u'ZENTEK GmbH & Co KG',
                             u'hqpp_period_product_id': None, u'is_b2b': None},
                            {u'tbs_product_level_id': '3.2 - Computers', u'tbs_id': u'El Kretsen', u'hqpp_period_product_id': None,
                             u'is_b2b': None}], u'weight_cat1': None,
                        u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [84713000], u'weight_package': None, u'product_name': u'ADAMO 13',
                        u'description': u'BASE,NBK,BTS,ADAMO,FCG13FRN~ADAMFCG13FRN - Adamo (Onyx) \u2013 SU9400'
                    },
                    {
                        u'sku': u'210-32413', u'diagonal': None, u'length_per_unit': None, u'hqpp_id': 15, u'sales_price': None,
                        u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': Decimal('0.350'), u'weight_cat3': None,
                        u'weight_per_unit': Decimal('1.599'), u'weight_cat4': None, u'height_per_unit': None, u'width_per_unit': None,
                        u'tbs_rowcontrol': [
                            {u'tbs_product_level_id': '32052 - Laptop Computer Without mercury-containing lighting', u'tbs_id': u'Eco-Syst\xe8mes',
                             u'hqpp_period_product_id': None, u'is_b2b': None},
                            {u'tbs_product_level_id': "3.1 - 'Personal' information and/or data processing", u'tbs_id': u'ZENTEK GmbH & Co KG',
                             u'hqpp_period_product_id': None, u'is_b2b': None},
                            {u'tbs_product_level_id': '3.2 - Computers', u'tbs_id': u'El Kretsen', u'hqpp_period_product_id': None,
                             u'is_b2b': None}], u'weight_cat1': None,
                        u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [84713000], u'weight_package': None,
                        u'product_name': u'ALIENWARE M11X',
                        u'description': u'Base: Alienware M11x Lunar Shadow~Base : Alienware M11x Ombre lunaire'
                    },
                    {
                        u'sku': u'210-29615', u'diagonal': None, u'length_per_unit': None, u'hqpp_id': 15, u'sales_price': None,
                        u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                        u'weight_per_unit': Decimal('3.837'), u'weight_cat4': None, u'height_per_unit': None, u'width_per_unit': None,
                        u'tbs_rowcontrol': [
                            {u'tbs_product_level_id': '36040 - Small IT Equipment <7', u'tbs_id': u'Eco-Syst\xe8mes',
                             u'hqpp_period_product_id': None, u'is_b2b': None},
                            {u'tbs_product_level_id': "3.1 - 'Personal' information and/or data processing", u'tbs_id': u'ZENTEK GmbH & Co KG',
                             u'hqpp_period_product_id': None, u'is_b2b': None},
                            {u'tbs_product_level_id': '3.2 - Computers', u'tbs_id': u'El Kretsen', u'hqpp_period_product_id': None,
                             u'is_b2b': None}], u'weight_cat1': None,
                        u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [84714900], u'weight_package': None,
                        u'product_name': u'ALIENWARE AREA51',
                        u'description': u'BASE,PHOBOS,ANW-DT,AREA 51~Alienware : Area 51 Lunar Shadow Standard Desktop'
                    },
                    {
                        u'sku': u'210-30013', u'diagonal': None, u'length_per_unit': None, u'hqpp_id': 15, u'sales_price': None,
                        u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                        u'weight_per_unit': Decimal('2.283'), u'weight_cat4': None, u'height_per_unit': None, u'width_per_unit': None,
                        u'tbs_rowcontrol': [
                            {u'tbs_product_level_id': '45030 - SMALL CONSUMER EQUIPMENT', u'tbs_id': u'Eco-Syst\xe8mes',
                             u'hqpp_period_product_id': None, u'is_b2b': None},
                            {u'tbs_product_level_id': '4.2 - Other consumer equipment (except television sets)', u'tbs_id': u'ZENTEK GmbH & Co KG',
                             u'hqpp_period_product_id': None, u'is_b2b': None},
                            {u'tbs_product_level_id': '4.3 - Portable consumer equipment', u'tbs_id': u'El Kretsen',
                             u'hqpp_period_product_id': None, u'is_b2b': None}],
                        u'weight_cat1': None,
                        u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85286100], u'weight_package': None, u'product_name': u'DELL 1210S',
                        u'description': u'1210S Value Projector~Dell 1210S Projector'
                    }
                ]
            }, {
                'Philips Consumer Lifestyle HQ': [
                    {u'sku': u'BG2036/32', u'diagonal': None, u'length_per_unit': Decimal('17.500'), u'hqpp_id': 16, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('0.109'), u'weight_cat4': None, u'height_per_unit': Decimal('5.200'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '2/C04 - Personal care appliance', u'tbs_id': u'Wecycle', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '25020 - SHA (excluding Vacuum cleaner)', u'tbs_id': u'Eco-Syst\xe8mes',
                          u'hqpp_period_product_id': None, u'is_b2b': None}
                     ], u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85101000], u'weight_package': None,
                     u'product_name': u'BODYSHAVER TRAPEZOID', u'description': u''},

                    {u'sku': u'FC8633/01', u'diagonal': None, u'length_per_unit': Decimal('29.000'), u'hqpp_id': 16, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('5.400'), u'weight_cat4': None, u'height_per_unit': Decimal('30.000'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '2/C05 - Vacuum/floor cleaner', u'tbs_id': u'Wecycle', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {
                             u'tbs_product_level_id': '25010 - Refrigerator Freezer <= 40 kg Refrigerant with GWP > 15 25010. Vacuum cleaner without plastic parts > 25 grams containing brominated flame retardants',
                             u'tbs_id': u'Eco-Syst\xe8mes', u'hqpp_period_product_id': None, u'is_b2b': None},
                     ], u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85081900], u'weight_package': None,
                     u'product_name': u'VAC.CLNR.BAGLESS POW',
                     u'description': u''},

                    {u'sku': u'GC4845/02', u'diagonal': Decimal('12.50'), u'length_per_unit': Decimal('15.200'), u'hqpp_id': 16, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('1.588'), u'weight_cat4': None, u'height_per_unit': Decimal('30.100'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '2/C02 - Household appliance (small)', u'tbs_id': u'Wecycle', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '25020 - SHA (excluding Vacuum cleaner)', u'tbs_id': u'Eco-Syst\xe8mes',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                     ], u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85164000], u'weight_package': None,
                     u'product_name': u'ST.IRON HV-FU-SOLG', u'description': u''},

                    {u'sku': u'HX6732/02', u'diagonal': None, u'length_per_unit': Decimal('18.670'), u'hqpp_id': 16, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('0.268'), u'weight_cat4': None, u'height_per_unit': Decimal('4.930'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '2/C04 - Personal care appliance', u'tbs_id': u'Wecycle', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '11021 - Refrigerator Freezer <= 40 kg Refrigerant with GWP > 15',
                          u'tbs_id': u'Eco-Syst\xe8mes', u'hqpp_period_product_id': None, u'is_b2b': None},
                     ], u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85098000], u'weight_package': None,
                     u'product_name': u'EL.TOOTHBRUSH ATLAS', u'description': u''},

                    {u'sku': u'SCD570/00', u'diagonal': None, u'length_per_unit': Decimal('10.500'), u'hqpp_id': 16, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('0.322'), u'weight_cat4': None, u'height_per_unit': Decimal('12.000'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '3/C10 - IT-/office appliance (small)', u'tbs_id': u'Wecycle', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '32040 - SMALL MONITOR <=7 kg et >= 7', u'tbs_id': u'Eco-Syst\xe8mes',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                     ], u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85176200], u'weight_package': None,
                     u'product_name': u'DECT BABY MONITOR WE', u'description': u''}
                ]
            }, {
                'Samsung Electronics Europe': [
                    {u'sku': u'LT22D390EW/EN', u'diagonal': Decimal('22.00'), u'length_per_unit': Decimal('57.700'), u'hqpp_id': 17,
                     u'sales_price': None, u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('3.750'), u'weight_cat4': None, u'height_per_unit': Decimal('13.800'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '4/C03 - TV/display (flatscreen)', u'tbs_id': u'Wecycle', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '162-14 - TV LCD 21-23"', u'tbs_id': u'Fundación ECOTIC', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '4.2. - Television sets', u'tbs_id': u'ElektroEko SA', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '4.2.3 - Television sets >15" <=32"_ECR', u'tbs_id': u'Consorzio Re.media',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': 'C2000700 - Television from 15" (36cm) screen diagonal, Video projector',
                          u'tbs_id': u'SWICO Recycling', u'hqpp_period_product_id': None,
                          u'is_b2b': None}],
                     u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85287240], u'weight_package': None,
                     u'product_name': u'LED MFM,T22D390EW,21.5,NETHERLANDS,WBD9', u'description': u''},

                    {u'sku': u'HMX-H200BP/EDC', u'diagonal': None, u'length_per_unit': Decimal('14.900'), u'hqpp_id': 17, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('0.271'), u'weight_cat4': None, u'height_per_unit': Decimal('9.500'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '4/C01 - Audio/video appliance (portable)', u'tbs_id': u'Wecycle',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '161-32 - VIDEO/PHOTO CAMERA', u'tbs_id': u'Fundación ECOTIC',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '4.3. - Videocameras', u'tbs_id': u'ElektroEko SA',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '4.3.1 - Video cameras_INT', u'tbs_id': u'Consorzio Re.media',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {
                             u'tbs_product_level_id': 'F2000200 - CD/DVD/Blu-Ray Recorder/Player, Mini-Midi system, Stationary game console (X-box, PS, etc)',
                             u'tbs_id': u'SWICO Recycling', u'hqpp_period_product_id': None, u'is_b2b': None}],
                     u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85258030], u'weight_package': None,
                     u'product_name': u'Digital camcorder', u'description': u''},

                    {u'sku': u'AR07FSFPDGMNEU', u'diagonal': None, u'length_per_unit': Decimal('106.400'), u'hqpp_id': 17, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('7.890'), u'weight_cat4': None, u'height_per_unit': Decimal('32.000'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '1/P50 - Air conditioner (professional/built-in) < 1kg coolant', u'tbs_id': u'Wecycle',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '127-1 - AIR CONDITIONING APPLIANCES (split)', u'tbs_id': u'Fundación ECOTIC',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '1.17. - Air conditioner appliances', u'tbs_id': 'ElektroEko SA',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '1.17.1 - Air conditioning appliances_INT', u'tbs_id': u'Consorzio Re.media',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None}],
                     u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [84151090], u'weight_package': None,
                     u'product_name': u'RAC,2.0,KW,SETIN,HP,R410A', u'description': u''},

                    {u'sku': u'AC071HBMDKH/EU', u'diagonal': None, u'length_per_unit': Decimal('106.400'), u'hqpp_id': 17, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('24.300'), u'weight_cat4': None, u'height_per_unit': Decimal('32.000'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '1/P50 - Air conditioner (professional/built-in) < 1kg coolant', u'tbs_id': u'Wecycle',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '127-1 - AIR CONDITIONING APPLIANCES (split)', u'tbs_id': u'Fundación ECOTIC',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '1.17. - Air conditioner appliances', u'tbs_id': 'ElektroEko SA',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '1.17.1 - Air conditioning appliances_INT', u'tbs_id': u'Consorzio Re.media',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None}],
                     u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [84158100], u'weight_package': None, u'product_name': u'SELS,CAC,28.500',
                     u'description': u''},

                    {u'sku': u'RB29FSRNDWW/EF', u'diagonal': None, u'length_per_unit': Decimal('64.000'), u'hqpp_id': 17, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('64.910'), u'weight_cat4': None, u'height_per_unit': Decimal('186.000'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '1/C16 - Fridge', u'tbs_id': u'Wecycle', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '112 - REFRIGERATOR AND FREEZERr > =45 < 70 KG', u'tbs_id': u'Fundación ECOTIC',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '1.2. - Refrigerators', u'tbs_id': u'ElektroEko SA', u'hqpp_period_product_id': None,
                          u'is_b2b': None},
                         {u'tbs_product_level_id': '1.1.1 - Large cooling appliances_INT', u'tbs_id': u'Consorzio Re.media',
                          u'hqpp_period_product_id': None,
                          u'is_b2b': None}],
                     u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [84181080], u'weight_package': None,
                     u'product_name': u'REF;290LT,230V/50HZ,SNOW WHITE,UCP-2,FRA', u'description': u''},

                    {u'sku': u'WAM250/EN', u'diagonal': None, u'length_per_unit': Decimal('21.000'), u'hqpp_id': 17, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('0.160'), u'weight_cat4': None, u'height_per_unit': Decimal('15.900'), u'width_per_unit': None,
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '4/C02 - Audio/video appliance (not portable)', u'tbs_id': u'Wecycle',
                          u'hqpp_period_product_id': None, u'is_b2b': None}],
                     u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85176200], u'weight_package': None,
                     u'product_name': u'AV RECEIVER,WAM250,NETHERLANDS', u'description': u''},

                    {u'sku': u'WF0600NXWG/XEC', u'product_name': u'Washing Machine', u'diagonal': None, u'length_per_unit': Decimal('60.000'),
                     u'hqpp_id': 17, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('64.000'), u'weight_cat4': None, u'height_per_unit': Decimal('85.000'),
                     u'width_per_unit': Decimal('55.000'),
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '4/C02 - Audio/video appliance (not portable)', u'tbs_id': u'Wecycle',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '115 - WASHING MACHINE', u'tbs_id': u'Fundación ECOTIC',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '1.5a. - Washing machines', u'tbs_id': u'ElektroEko SA',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '1.5.1 - Washing machines_INT', u'tbs_id': u'Consorzio Re.media',
                          u'hqpp_period_product_id': None, u'is_b2b': None}],
                     u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [84501190], u'weight_package': None,
                     u'description': u''},

                    {u'sku': u'SL-C460FW/SEE', u'product_name': u'LASER MFP-COLOR,SL-C460FW,18,4,SET', u'diagonal': None,
                     u'length_per_unit': Decimal('40.600'), u'hqpp_id': 17, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('13.980'), u'weight_cat4': None, u'height_per_unit': Decimal('36.200'),
                     u'width_per_unit': Decimal('33.350'),
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '3/C08 - Printer/scanner', u'tbs_id': u'Wecycle',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '147 - Printers', u'tbs_id': u'Fundación ECOTIC',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '3B.5. - Printers', u'tbs_id': u'ElektroEko SA',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '3.2.5 - Printers', u'tbs_id': u'Consorzio Re.media',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '1000070 - Printer', u'tbs_id': u'SWICO Recycling',
                          u'hqpp_period_product_id': None, u'is_b2b': None}],
                     u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [84433180], u'weight_package': None,
                     u'description': u''},

                    {u'sku': u'S19C200NW', u'product_name': u'LED MON,S19C200NW,19,NETHERLANDS,WGE2/S', u'diagonal': Decimal('19.00'),
                     u'length_per_unit': Decimal('44.140'), u'hqpp_id': 17, u'sales_price': None,
                     u'weight_documentation': None, u'unu_id': u'', u'hs': u'', u'weight_batteries': None, u'weight_cat3': None,
                     u'weight_per_unit': Decimal('2.800'), u'weight_cat4': None, u'height_per_unit': Decimal('34.880'),
                     u'width_per_unit': Decimal('17.000'),
                     u'tbs_rowcontrol': [
                         {u'tbs_product_level_id': '3/C10 - IT-/office appliance (small)', u'tbs_id': u'Wecycle',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '144-1 - Screens (MONITORS)', u'tbs_id': u'Fundación ECOTIC',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '3B.1.2. - Monitors/Screen', u'tbs_id': u'ElektroEko SA',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {u'tbs_product_level_id': '3.2.9 - User terminals and systems (monitors)', u'tbs_id': u'Consorzio Re.media',
                          u'hqpp_period_product_id': None, u'is_b2b': None},
                         {
                             u'tbs_product_level_id': '1000030 - Monitor/All-in-One_PC from 15" (36cm), Notebook/Tablet/Laptop (from 12"), PC, Projector',
                             u'tbs_id': u'SWICO Recycling',
                             u'hqpp_period_product_id': None, u'is_b2b': None}],
                     u'weight_cat1': None,
                     u'modulation': u'', u'weight_cat2': None, u'cn8_codes': [85285980], u'weight_package': None,
                     u'description': u''},
                ]
            }
        ]

    def _get_used_tbs_product_levels(self):
        return [{
            u'Eco-Systèmes': [
                {
                    "11021 - Refrigerator Freezer <= 40 kg Refrigerant with GWP > 15": None,
                    '36040 - Small IT Equipment <7': None,
                    "32052 - Laptop Computer Without mercury-containing lighting": None,
                    "45030 - SMALL CONSUMER EQUIPMENT": None,
                    "25020 - SHA (excluding Vacuum cleaner)": None,
                    "25010 - Refrigerator Freezer <= 40 kg Refrigerant with GWP > 15 25010. Vacuum cleaner without plastic parts > 25 grams containing brominated flame retardants": None,
                    "32040 - SMALL MONITOR <=7 kg et >= 7": None,

                }
            ],
            u'ZENTEK GmbH & Co KG': [
                {
                    "3.1 - 'Personal' information and/or data processing": None,
                    "4.2 - Other consumer equipment (except television sets)": None
                }
            ],
            'Wecycle': [
                {
                    "1/C16 - Fridge": None,
                    "1/C14 - Washing machine": None,
                    "2. - Small Household Appliances": None,
                    "2/C02 - Household appliance (small)": None,
                    "2/C04 - Personal care appliance": None,
                    "2/C05 - Vacuum/floor cleaner": None,
                    "3/C10 - IT-/office appliance (small)": None,
                    "3/C08 - Printer/scanner": None,
                    "4/C01 - Audio/video appliance (portable)": None,
                    "4/C02 - Audio/video appliance (not portable)": None,
                    "4/C03 - TV/display (flatscreen)": None,
                    "1/P50 - Air conditioner (professional/built-in) < 1kg coolant": None,

                }
            ],
            'El Kretsen': [
                {
                    '3.2 - Computers': None,
                    '4.3 - Portable consumer equipment': None
                }
            ],

            u'Fundación ECOTIC': [
                {
                    '162-14 - TV LCD 21-23"': None,
                    '161-32 - VIDEO/PHOTO CAMERA': None,
                    "127-1 - AIR CONDITIONING APPLIANCES (split)": None,
                    '112 - REFRIGERATOR AND FREEZERr > =45 < 70 KG': None,
                    "115 - WASHING MACHINE": None,
                    '147 - Printers': None,
                    "144-1 - Screens (MONITORS)": None
                }
            ],

            'ElektroEko SA': [
                {
                    '4.3. - Videocameras': None,
                    '4.2. - Television sets': None,
                    '1.17. - Air conditioner appliances': None,
                    '1.2. - Refrigerators': None,
                    "1.5a. - Washing machines": None,
                    "3B.5. - Printers": None,
                    "3B.1.2. - Monitors/Screen": None
                }
            ],

            'Consorzio Re.media': [
                {
                    '4.3.1 - Video cameras_INT': None,
                    '4.2.3 - Television sets >15" <=32"_ECR': None,
                    '1.17.1 - Air conditioning appliances_INT': None,
                    '1.1.1 - Large cooling appliances_INT': None,
                    "1.5.1 - Washing machines_INT": None,
                    "3.2.5 - Printers": None,
                    "3.2.9 - User terminals and systems (monitors)": None
                }
            ],

            'SWICO Recycling': [
                {
                    'F2000200 - CD/DVD/Blu-Ray Recorder/Player, Mini-Midi system, Stationary game console (X-box, PS, etc)': None,
                    'C2000700 - Television from 15" (36cm) screen diagonal, Video projector': None,
                    "1000070 - Printer": None,
                    '1000030 - Monitor/All-in-One_PC from 15" (36cm), Notebook/Tablet/Laptop (from 12"), PC, Projector': None
                }
            ],

            'Stiftung SENS': [
                {
                    '3.2 - Computers': None,
                    '4.3 - Portable consumer equipment': None
                }
            ],

            'ASEKOL SK s.r.o.': [
                {
                    '3.2 - Computers': None,
                    '4.3 - Portable consumer equipment': None
                }
            ],

            'Asekol a.s.': [
                {
                    '3.2 - Computers': None,
                    '4.3 - Portable consumer equipment': None
                }
            ],
        }]

    def _get_declaration_states(self):
        return [{
            u'declaration_quantity': 60, u'lpp_id': 'Samsung Benelux BV', u'lines': [
                {
                    u'sku': u'AC071HBMDKH/EU', u'quantity': 50, u'line_id': None, u'hqpp_period_product_id': 37
                }, {
                    u'sku': u'HMX-H200BP/EDC', u'quantity': 10, u'line_id': None, u'hqpp_period_product_id': 28
                }
            ],
            u'month': 3, u'year': 2015
        }, {
            u'declaration_quantity': 6000, u'lpp_id': 'Samsung Iberia SA', u'lines': [
                {
                    u'sku': u'SL-C460FW/SEE', u'quantity': 1000, u'line_id': None, u'hqpp_period_product_id': 51
                }, {
                    u'sku': u'S19C200NW', u'quantity': 5000, u'line_id': None, u'hqpp_period_product_id': 56
                }
            ],
            u'month': 12, u'year': 2014
        }, {
            u'declaration_quantity': 6000, u'lpp_id': 'Samsung Iberia SA', u'lines': [
                {
                    u'sku': u'SL-C460FW/SEE', u'quantity': 5000, u'line_id': None, u'hqpp_period_product_id': 51
                }, {
                    u'sku': u'S19C200NW', u'quantity': 1000, u'line_id': None, u'hqpp_period_product_id': 56
                }
            ],
            u'month': 6, u'year': 2015
        }]
