# -*- coding: utf-8 -*-


# Copyright (c) 2015 BaseSoft B.V.
# See LICENSE for details.


import os
from datetime import date
from decimal import Decimal
from basesoft.util.virtual_date import set_date
from basesoft.web.contrib.scheduler.controllers import SchedulerServerController
from we.declaration.controllers import WeDeclarationController
from we.declaration.models import WeDeclaration
from we.product.models import WeCN8, WeTbsProductLevel, WeHqppRegulationPeriodProduct
from we.test.selenium.we_selenium import WeSeleniumTestCase


class TestCase(WeSeleniumTestCase):
    def setUp(self):
        super(TestCase, self).setUp()

        self.connect_db()

        self._operator_account = self._create_operator_account()

    def test_save_and_update_declaration(self):
        set_date(date(2015,1,1))
        cn8 = self.sa_session.query(WeCN8).first()
        member, lpp, tbs_product_level, tbs = self.create_lpp(member_account=True)
        pl1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        rp1 = self.create_tbs_regulation_period(tbs.id, 'label', 2014, 1, [{
            'id': pl1.id,
            'fee': Decimal('12.456')
        }])

        month = 'January'
        d = date(2015, 1, 1)

        # save 2 products
        self.add_hqpp_product(member.id, pl1.id, cn8.code, 'UK4456793', period=rp1.start_date)
        self.add_hqpp_product(member.id, pl1.id, cn8.code, 'UC123456', period=rp1.start_date)
        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open category manager
        self.click_iconbar('icon-we-declaration-manager')

        # create new declaration from manager menu
        self.click_menu('we_declaration_manager', menu_index=0, text='Add new declaration')
        self.wait_for_loading()
        # select lpp to load the sku in the combobox
        self.fill_form(panel_name='we-declaration-details', values={'lpp_id': ('select', lpp.name + ' - ' + tbs.name)})
        self.wait_for_loading()

        # select month
        self.fill_form(panel_name='we-declaration-details', values={'year': ('select', 'value=%d' % d.year)})
        self.wait_for_loading()

        # select month
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})
        self.wait_for_loading()

        # select sku
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=0, values={'sku': ('input_text', 'UK4456793')})
        # select month to trigger blur on the sku box
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})

        # set quantity to calculate totals
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=0, values={'quantity': ('input_text', '34')})

        # add another line
        self.click_button(panel_name='we-declaration-details', text='Add an additional row')
        self.wait_for_loading()
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=1, values={'sku': ('input_text', 'UC123456')})

        # select month to trigger blur on the sku box
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})

        # set quantity to calculate totals
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=1, values={'quantity': ('input_text', '56')})

        # save
        self.click_button(panel_name='we-declaration-details', text='Save')
        self.wait_for_loading2()

        # check that the new declaration shows up on the manager
        declaration = self.sa_session.query(WeDeclaration).order_by(WeDeclaration.id.desc()).first()
        self.filter_cq(panel_name='we_declaration_manager', filters=[('Declaration ID', 'Equal', declaration.id)])
        rows = self.cq_rows_length(panel_name='we_declaration_manager')
        self.assertEqual(rows, 1)

        # load  the declaration
        self.click_cq(panel_name='we_declaration_manager', row_index=0, col_name='declaration_id')
        self.wait_for_loading()

        # assert form
        values = {
            'lpp_id': ('select', lpp.name + ' - ' + tbs.name),
            'month': ('select', '%s' % month),
        }
        self.assert_form(panel_name='we-declaration-details', form_name='declaration_details_form', values=values)

        values = {
            'sku': ('input_text', 'UK4456793'),
            'quantity': ('input_text', '34'),
        }
        self.assert_form(panel_name='we-declaration-details', form_name='declaration_details_form', rowcontrol_row_index=0, values=values)

        # delete the first line
        self.click_button(panel_name='we-declaration-details', text='-')

        # save
        self.click_button(panel_name='we-declaration-details', text='Save')
        self.wait_for_loading()

        # check that there is only 1 line
        declaration = self.sa_session.query(WeDeclaration).order_by(WeDeclaration.id.desc()).first()
        self.assertEqual(len(declaration.lines), 1)

        # login as TBS user and check if we can view this declaration
        tbs_account = self._create_tbs_account(tbs)
        self.login(tbs_account.name, 'test_password')

        self.click_iconbar('icon-we-declaration-manager')
        self.wait_for_loading()

        self.filter_cq(panel_name='we_declaration_manager', filters=[('Declaration ID', 'Equal', declaration.id)])
        rows = self.cq_rows_length(panel_name='we_declaration_manager')
        self.assertEqual(rows, 1)

    def test_save_and_update_declaration_is_b2b(self):
        set_date(date(2015,1,1))
        cn8 = self.sa_session.query(WeCN8).first()
        member, lpp, tbs_product_level, tbs = self.create_lpp(member_account=True)

        pl1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        rp1 = self.create_tbs_regulation_period(tbs.id, 'label', 2014, 1, [{
            'id': pl1.id,
            'fee': Decimal('12.456')
        }])

        tbs.set_config('we.tbs.require.end.user.distinction', True)

        month = 'January'
        d = date(2015, 1, 1)

        # save 2 products
        self.add_hqpp_product(member.id, [pl1.id, pl1.id], cn8.code, 'UK4456793', is_b2b=True, period=rp1)
        self.add_hqpp_product(member.id, [pl1.id, pl1.id], cn8.code, 'UC123456', is_b2b=True, period=rp1)
        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open category manager
        self.click_iconbar('icon-we-declaration-manager')

        # create new declaration from manager menu
        self.click_menu('we_declaration_manager', menu_index=0, text='Add new declaration')
        self.wait_for_loading()
        # select lpp to load the sku in the combobox
        self.fill_form(panel_name='we-declaration-details', values={'lpp_id': ('select', lpp.name + ' - ' + tbs.name)})
        self.wait_for_loading()

        self.fill_form(panel_name='we-declaration-details', values={'year': ('select', 'value=%d' % d.year)})
        self.wait_for_loading()

        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})
        self.wait_for_loading()

        # select sku
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=0, values={'sku': ('input_text', 'UK4456793')})
        # select month to trigger blur on the sku box
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})

        # set quantity to calculate totals
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=0, values={'quantity': ('input_text', '34')})
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=1, values={'quantity': ('input_text', '34')})

        # add another line
        self.click_button(panel_name='we-declaration-details', text='Add an additional row')
        self.wait_for_loading()
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=2, values={'sku': ('input_text', 'UC123456')})

        # select month to trigger blur on the sku box
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})

        # set quantity to calculate totals
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=2, values={'quantity': ('input_text', '56')})
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=3, values={'quantity': ('input_text', '56')})

        # save
        self.click_button(panel_name='we-declaration-details', text='Save')
        self.wait_for_loading2()

        # check that the new declaration shows up on the manager
        declaration = self.sa_session.query(WeDeclaration).order_by(WeDeclaration.id.desc()).first()
        self.filter_cq(panel_name='we_declaration_manager', filters=[('Declaration ID', 'Equal', declaration.id)])
        rows = self.cq_rows_length(panel_name='we_declaration_manager')
        self.assertEqual(rows, 1)

        # load  the declaration
        self.click_cq(panel_name='we_declaration_manager', row_index=0, col_name='declaration_id')
        self.wait_for_loading()

        # assert form
        values = {
            'lpp_id': ('select', lpp.name + ' - ' + tbs.name),
            'month': ('select', '%s' % month),
        }
        self.assert_form(panel_name='we-declaration-details', form_name='declaration_details_form', values=values)

        values = {
            'sku': ('input_text', 'UK4456793'),
            'quantity': ('input_text', '34'),
        }
        self.assert_form(panel_name='we-declaration-details', form_name='declaration_details_form', rowcontrol_row_index=0, values=values)

        # delete the first line
        self.click_button(panel_name='we-declaration-details', text='-')

        # save
        self.click_button(panel_name='we-declaration-details', text='Save')
        self.wait_for_loading()

        # check that there are 3 lines
        declaration = self.sa_session.query(WeDeclaration).order_by(WeDeclaration.id.desc()).first()
        self.assertEqual(len(declaration.lines), 3)
        self.assertEqual(declaration.lines[0].hqpp_period_product.is_b2b, WeHqppRegulationPeriodProduct.IS_B2B_TRUE)

    def test_declaration_resubmit_with_new_product(self):

        # create declaration for 5th month with first product
        set_date(date(2015, 5, 1))
        cn8 = self.sa_session.query(WeCN8).first()
        member, lpp, tbs_product_level, tbs = self.create_lpp(member_account=True)

        tbs_product_level, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        pl1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        rp1 = self.create_tbs_regulation_period(tbs.id, 'label', 2014, 1, [{
            'id': tbs_product_level.id,
            'fee': Decimal('12.456')
        }, {
            'id': pl1.id,
            'fee': Decimal('1.456')
        }])

        month = 'May'
        d = date(2015, 1, 1)

        # save 1 product
        product1 = self.add_hqpp_product(member.id, tbs_product_level.id, cn8.code, 'UK4456793', period=rp1)

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open category manager
        self.click_iconbar('icon-we-declaration-manager')

        # create new declaration from manager menu
        self.click_menu('we_declaration_manager', menu_index=0, text='Add new declaration')
        self.wait_for_loading()

        # select lpp to load the sku in the combobox
        self.fill_form(panel_name='we-declaration-details', values={'lpp_id': ('select', lpp.name + ' - ' + tbs.name)})
        self.wait_for_loading()

        # select year
        self.fill_form(panel_name='we-declaration-details', values={'year': ('select', 'value=%d' % d.year)})
        self.wait_for_loading()
        # select month
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})
        self.wait_for_loading()

        # select sku
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=0, values={'sku': ('input_text', 'UK4456793')})
        self.wait_for_loading()

        # select month to trigger blur on the sku box
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})
        self.wait_for_loading()

        # set quantity to calculate totals
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=0, values={'quantity': ('input_text', '34')})

        # seems like the quantity has to be blurred because click_button doesn't work
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})
        # save
        self.click_button(panel_name='we-declaration-details', text='Save')
        self.wait_for_loading2(stable_time=4)

        # set date a little further
        set_date(date(2015, 7, 10))

        # check that the new declaration shows up on the manager
        declaration = self.sa_session.query(WeDeclaration).order_by(WeDeclaration.id.desc()).first()
        self.filter_cq(panel_name='we_declaration_manager', filters=[('Declaration ID', 'Equal', declaration.id)])
        rows = self.cq_rows_length(panel_name='we_declaration_manager')
        self.assertEqual(rows, 1)

        # load  the declaration
        self.click_cq(panel_name='we_declaration_manager', row_index=0, col_name='declaration_id')
        self.wait_for_loading()

        # add another line
        self.click_button(panel_name='we-declaration-details', text='Add an additional row')
        self.wait_for_loading()

        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=1, values={'sku': ('input_text', 'UC123456')})
        # blur the combobox
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})
        self.wait_for_loading()

        # get a cn8
        cn8 = self.sa_session.query(WeCN8).first()
        # this SKU does not exist
        # product details panel should be open to add a new product
        self.fill_form(panel_name='we_hqpp_product_panel', values={'weight_per_unit': Decimal('1.11'),
                                                                   'product_name': 'SKU_TEST',
                                                                   'cn8_codes': ('fancy-select', ['%s - %s' % (cn8.code, cn8.description)])})
        self.wait_for_loading2()
        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=0,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (pl1.label, pl1.description))})
        self.click_button(panel_name='we_hqpp_product_panel', text='Save and close')
        self.wait_for_loading()

        # set quantity to calculate totals
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=1, values={'quantity': ('input_text', '56')})

        # save
        self.click_button(panel_name='we-declaration-details', text='Save')
        self.wait_for_loading()

        self.assertEqual(len(declaration.lines), 2)
        self.assertEqual(declaration.lines[1].hqpp_period_product.tbs_regulation_period_product.tbs_product_level, pl1)

    def test_declaration_fixed_annual_fee(self):
        # create declaration for 5th month with first product
        set_date(date(2015, 5, 1))
        cn8 = self.sa_session.query(WeCN8).first()
        member, lpp, tbs_product_level, tbs = self.create_lpp(member_account=True)

        pl1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs,
                                                 invoice_basis=WeTbsProductLevel.INVOICE_BASED_ON_FIXED_ANNUAL_FEE)

        rp1 = self.create_tbs_regulation_period(tbs.id, 'label', 2014, 1, [{
            'id': pl1.id,
            'fee': Decimal('1.456')
        }])

        month = 'May'
        d = date(2015, 1, 1)

        # save 1 product
        product1 = self.add_hqpp_product(member.id, pl1.id, cn8.code, 'UK4456793', period=rp1)

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open category manager
        self.click_iconbar('icon-we-declaration-manager')

        # create new declaration from manager menu
        self.click_menu('we_declaration_manager', menu_index=0, text='Add new declaration')
        self.wait_for_loading()

        # select lpp to load the sku in the combobox
        self.fill_form(panel_name='we-declaration-details', values={'lpp_id': ('select', lpp.name + ' - ' + tbs.name)})
        self.wait_for_loading()

        # select year
        self.fill_form(panel_name='we-declaration-details', values={'year': ('select', 'value=%d' % d.year)})
        self.wait_for_loading()
        # select month
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})
        self.wait_for_loading()

        # select sku
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=0, values={'sku': ('input_text', 'UK4456793')})
        self.wait_for_loading()

        # select month to trigger blur on the sku box
        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})
        self.wait_for_loading()

        # set quantity to calculate totals
        self.fill_form(panel_name='we-declaration-details', rowcontrol_row_index=0, values={'quantity': ('input_text', '34')})

        self.fill_form(panel_name='we-declaration-details', values={'month': ('select', '%s' % month)})

    def test_declaration_import(self):
        set_date(date(2015, 6, 10))

        SchedulerServerController().enable_task('we.declaration.schedule.WeDeclarationImportTask')

        member, lpp, tbs_product_level, tbs = self.create_lpp()
        pl1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='2222')
        pl2, tbs = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='1111')

        tbs.set_config('we.tbs.require.end.user.distinction', True)
        rp = self.create_tbs_regulation_period(tbs.id, 'Test RP', 2015, 1, [{
            'id': tbs_product_level.id,
            'fee': Decimal('20.12')
        },{
            'id': pl1.id,
            'fee': Decimal('33.33')
        },{
            'id': pl2.id,
            'fee': Decimal('0.33')
        }])

        code = self.sa_session.query(WeCN8).first()

        product = self.add_hqpp_product(member.id, [tbs_product_level.id, pl1.id], code.code, 'UC389458', is_b2b=True)
        product1 = self.add_hqpp_product(member.id, [pl1.id, pl2.id], code.code, 'WEE34958', is_b2b=True)

        headers = ['LPP name', 'LPP_ID', 'Year', 'Month', 'SKU', 'B2B/B2C', 'Quantity']
        row1 = ['garbage', lpp.id, 2015, 3, 'UC389458', 'B2B', 5]
        row2 = ['garbage', lpp.id, 2015, 3, 'UC389458', 'B2C', 1]
        row3 = ['garbage', lpp.id, 2015, 3, 'WEE34958', 'B2B', 10]
        row4 = ['garbage', lpp.id, 2015, 3, 'SK596853', 'b2B', 3]

        file_path = os.path.join(os.path.dirname(__file__), os.pardir, 'files', 'test_declaration_sel.xlsx')

        import openpyxl.workbook as workbook
        book = workbook.Workbook()
        sheet1 = book.get_active_sheet()
        sheet1.append(headers)
        sheet1.append(row1)
        sheet1.append(row2)
        sheet1.append(row3)
        sheet1.append(row4)
        book.save(file_path)

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open category manager
        self.click_iconbar('icon-we-declaration-manager')

        # create new declaration from manager menu
        self.click_menu('we_declaration_manager', menu_index=0, text='Import declaration file')
        self.wait_for_loading()

        self.fill_form(panel_name='we-declaration-import-wizard', values={'hqpp_id': ('select', member.name)})
        self.wait_for_loading()

        # select file
        self.fill_form(panel_name='we-declaration-import-wizard', values={
            'upload_declaration': ('upload', file_path),
        })

        self.click_button(panel_name='we-declaration-import-wizard', text=u'Next »')
        self.wait_for_loading()

        # we should be able to add missing SKU
        self.click_button(panel_name='we-declaration-import-wizard', text='Add SKUs')
        self.wait_for_loading()

        code = self.sa_session.query(WeCN8).first()
        values = {
            'product_name': 'NEW PRODUCT',
            'weight_per_unit': Decimal('2.221'),
            'cn8_codes': ('fancy-select', ['%s - %s' % (code.code, code.description)])
        }
        self.fill_form(panel_name='we_hqpp_product_panel', values=values)
        self.wait_for_loading()

        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=0,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (pl2.label,
                                                                               pl2.description))})

        self.click_button(panel_name='we_hqpp_product_panel', text='Save and close')
        self.wait_for_loading()

        self.click_button(panel_name='we-declaration-import-wizard', text=u'Finish')
        self.wait_for_loading()

        # we should have a declaration saved
        self.filter_cq('we_declaration_manager', filters=[('LPP', 'Contains', lpp.name)])

        self.assert_cq('we_declaration_manager', row_index=0, data={'total_quantity': '19'})

