# -*- coding: utf-8 -*-

'''
Created on Dec 17, 2014

@author: marten
'''

from twisted.trial.unittest import SkipTest

from decimal import Decimal

from datetime import date

from basesoft.util.virtual_date import set_date
from we.product.models import WeCN8
from we.test.selenium.we_selenium import WeSeleniumTestCase
from we.member.models import WeHqppLicense
from we.member.controllers import WeMemberController


class TestCase(WeSeleniumTestCase):

    def setUp(self):
        super(TestCase, self).setUp()

        self.connect_db()
        self._operator_account = self._create_operator_account()
        self.reset_vat()

    def test_create_member_as_operator(self):
        self._create_tbs(self._operator_account.id)

        self.login(self._operator_account.name, 'test_password')

        self.click_iconbar('icon-we-member-wizard', hover='icon-we-member-manager')
        self.wait_for_loading()

        comp = self._uniquestring('c')
        # fill out the wizard company page.
        company_forms_data = {
            'company_form': {
                'name': comp,
                'website': 'http://member.com',
                'vat_no': 'RO1630615123457'
            },
            'address_form': {
                'street': 'Member Street',
                'street_2': 'Member Street 2',
                'city': 'Amsterdam',
                'postcode': '1000AA',
                'country': ('select', 'Belgium'),
                'state': 'NH'
            },
            'bank_account_form': {
                'number': "1234567890",
                'iban': "GB82WEST12345698765432",
                'bic': "UNCRIT2B912",
            }
        }

        self.fill_forms(panel_name='we-member-wizard', forms_data=company_forms_data)
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # contact/invoice person info
        person_forms_data = {
            'person_form': {
                'last_name': 'Member Contact Last Name',
                'first_name': 'Member Contact First Name',
                'email': 'test-member@mail-test.basesoft.com',
                'preferred_locale': ('select', 'English'),
                'gender': ('select', 'Male'),
                'phone': '234234235',
                'mobile_phone': '123412345',
            },
            'invoice_person_form': {
                'is_same_person_as': ('checkbox', 'true')
            }
        }
        self.fill_forms(panel_name='we-member-wizard', forms_data=person_forms_data)
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # create account info
        self.fill_forms(panel_name='we-member-wizard', forms_data={
            'skip_account': {
                'skip_account': ('checkbox', True),
            }
        })
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # click second radio button for adding LPPs and check the LPP details is opened after Finish
        self.fill_form(panel_name='we-member-wizard', values={'lpp_selection': ('radio', 1)})
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # this is the Finish page. Just clicky button
        self.click_button(panel_name='we-member-wizard', text=u'Finish')
        self.wait_for_panel(panel_name='we-company-details')

        member = self.sa_session.query(WeHqppLicense).filter(WeHqppLicense.name==comp).first()
        self.assertEqual(len(member.default_group.accounts), 0)

    def test_create_member_with_account(self):
        vats = self.get_vat_numbers()

        self.login(self._operator_account.name, 'test_password')

        self.click_iconbar('icon-we-member-wizard', hover='icon-we-member-manager')
        self.wait_for_loading()

        comp = self._uniquestring('c')
        # fill out the wizard company page.
        company_forms_data = {
            'company_form': {
                'name': comp,
                'website': 'http://member.com',
                'vat_no': vats[0]
            },
            'address_form': {
                'street': 'Member Street',
                'street_2': 'Member Street 2',
                'city': 'Amsterdam',
                'postcode': '1000AA',
                'country': ('select', 'Belgium'),
                'state': 'NH'
            },
            'bank_account_form': {
                'number': "1234567890",
                'iban': "GB82WEST12345698765432",
                'bic': "UNCRIT2B912",
            }
        }

        self.fill_forms(panel_name='we-member-wizard', forms_data=company_forms_data)
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # contact/invoice person info
        person_forms_data = {
            'person_form': {
                'last_name': 'Member Contact Last Name',
                'first_name': 'Member Contact First Name',
                'email': 'test-member@mail-test.basesoft.com',
                'preferred_locale': ('select', 'English'),
                'gender': ('select', 'Male'),
                'phone': '234234235',
                'mobile_phone': '123412345',
            },
            'invoice_person_form': {
                'is_same_person_as': ('checkbox', 'true')
            }
        }
        self.fill_forms(panel_name='we-member-wizard', forms_data=person_forms_data)
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # create account info
        self.fill_forms(panel_name='we-member-wizard', forms_data={
            'account_details': {
                'account_name': ('input_text', self._uniquestring('Acc')[:10]),
            },
            'set_password_form': {
                'new_password': ('input_text', 'KH76daksuhd&*^'),
                'new_password_verify': ('input_text', 'KH76daksuhd&*^')
            },
            "account_person_form": {
                'last_name': 'MC Last Name',
                'first_name': 'MC First Name',
                'email': 'test-mc@test.basesoft.com',
                'preferred_locale': ('select', 'English'),
                'gender': ('select', 'Male'),
                'phone': '234234235',
                'mobile_phone': '123412345',
            }
        })
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # this is the Finish page. Just clicky button
        self.click_button(panel_name='we-member-wizard', text=u'Finish')
        self.wait_for_loading()

        member = self.sa_session.query(WeHqppLicense).filter(WeHqppLicense.name==comp).first()
        self.assertEqual(len(member.lpps), 0)
        self.assertEqual(len(member.default_group.accounts), 1)

    def test_update_member_as_operator(self):

        member, member_account = self._create_member(self._operator_account.id, create_account=True)
        member = member_account.default_group.license

        self.login(self._operator_account.name, 'test_password')

        self.click_iconbar('icon-we-member-manager')
        self.wait_for_loading()

        # filter to the previously created member.
        self.filter_cq(panel_name='we-member-manager', filters=[('Producer', 'Equal', member.name)])
        self.wait_for_loading()

        # open the master data panel
        self.click_cq(panel_name='we-member-manager', row_index=0, col_name='member_name')
        self.wait_for_loading()

        self.fill_form(panel_name='we-member-details', form_name='company_form', values={'name': 'update comp name'})
        self.fill_form(panel_name='we-member-details', form_name='invoice_person_form', values={'is_same_person_as': ('checkbox', True)})
        self.fill_form(panel_name='we-member-details', form_name='bank_account_form', values={'iban': "IL620108000000099999999",
                                                                                              'bic': "DEUTDEFF"})
        self.fill_form(panel_name='we-member-details', form_name='address_form', values={'street': 'Heregacht 222',
                                                                                         'postcode': '1112XP',
                                                                                         'city': 'Leiden',
                                                                                         'country': ('select', 'Netherlands')})
        self.fill_form(panel_name='we-member-details', form_name='person_form', values={'preferred_locale': ('select', 'English')})

        self.click_button(panel_name='we-member-details', text='Save')
        self.wait_for_loading()

        # verify
        self.sa_session.expire(member)

        self.assertEqual(member.name, 'update comp name')
        self.assertEqual(member.temp_company, None) # operator has auto approval.


    def test_update_member_as_member(self):
        pass

    def test_add_lpp_to_member(self):
        # create member without LPP
        member, member_account = self._create_member(self._operator_account.id, create_account=True)
        member = member_account.default_group.license

        # create TBS for selection
        tbs = self._create_tbs(self._operator_account.id)

        self.login(self._operator_account.name, 'test_password')

        self.click_iconbar('icon-we-member-manager')
        self.wait_for_loading()

        # filter to the previously created member.
        self.filter_cq(panel_name='we-member-manager', filters=[('Producer', 'Equal', member.name)])
        self.wait_for_loading()

        # click column with "Add lpp"
        self.click_cq(panel_name='we-member-manager', row_index=0, col_name='lpp')
        self.wait_for_loading()

        # fill out form
        self.fill_form(panel_name='we-company-details', values={
            'name': 'Down with LPP',
            'vat_no': 'CZ10000101'
        })

        self.fill_form(panel_name='we-company-details', form_name='lpp_form', rowcontrol_row_index=0,
                       values={
                                'tbs_id': ('select', tbs.name),
                                'invoice_relation_id': 'ab11',
                                'lpp_relation_id': 123
        })

        self.fill_form(panel_name='we-company-details', form_name='address_form',
                       values={
                                'street': 'New Ark 52',
                                'postcode': '1111ca',
                                'city': 'Paris',
                                'country': ('select', u'France')
        })

        self.fill_form(panel_name='we-company-details', form_name='bank_account_form',
                       values={
                                'iban': 'IL620108000000099999999',
                                'bic': 'DEUTDEFF',
        })

        self.click_button(panel_name='we-company-details', text='Save')
        self.wait_for_loading()
        # verify

        self.close_panel(panel_name='we-member-manager')
        self.click_iconbar('icon-we-member-manager')
        self.wait_for_loading()

        # filter to the previously created member.
        self.filter_cq(panel_name='we-member-manager', filters=[('Producer', 'Equal', member.name)])
        self.wait_for_loading()

        self.assert_cq(panel_name='we-member-manager', row_index=0, data={
            'lpp': 'Down with LPP',
            'lpp_vat_no': 'CZ10000101',
            'tbs': tbs.name,
            'lpp_relation_id': '123',
            'invoice_relation_id': 'ab11'
        })

    def test_delete_lpp_from_member(self):
        raise SkipTest('Currently LPPs are enabled on save for easier testing. Remove the skip test when it is over.')

        member_account = self._create_member(self._operator_account.id, create_account=True)
        member = member_account.default_group.license

        # create TBS for selection
        tbs = self._create_tbs(self._operator_account.id)
        c = WeMemberController(self.sa_session, account_id=self._operator_account.id)
        state = {
            'vat_no': 'TEST',
            'name': 'REMOVE ME',
            'lpp': {
                'tbs_id': tbs.id,
                'has_authorized_representative': False
            }
        }
        c.add_lpp_to_hqpp(member.id, state)

        self.login(self._operator_account.name, 'test_password')

        self.click_iconbar('icon-we-member-manager')
        self.wait_for_loading()

        # filter to the previously created member.
        self.filter_cq(panel_name='we-member-manager', filters=[('Producer', 'Equal', member.name)])
        self.wait_for_loading()

        self.click_cq(panel_name='we-member-manager', row_index=0, col_name='row_select', extra_css=' input')
        self.click_menu(panel_name='we-member-manager', text='Remove local producer partner')
        self.wait_for_loading()

        self.click_button('dialog-question', text='Yes')
        self.wait_for_loading()

    def test_create_account_limited_for_lpp(self):
        pass

    def test_add_and_load_hqpp_product(self):
        """
        Test that HQPP can add products
        """
        set_date(date(2015, 5, 5))
        member, lpp, tbs_product_level, tbs = self.create_lpp(member_account=True)
        member_account = member.default_group.accounts[0]
        self._attach_permissions_to_group(member.default_group, 'we_view_products', 'view_dashboard', 'we_view_tbs_product_level')

        categories = [{
            'id': tbs_product_level.id,
            'fee': Decimal('20.12')
        }]
        rp = self.create_tbs_regulation_period(tbs.id, self._uniquestring('RP'), 2015, 1, categories)

        self.login(member_account.name, 'abcd123456')

        self.click_iconbar('icon-we-hqpp-product-manager', 'icon-we-member-manager')
        self.wait_for_loading()

        self.click_menu(panel_name='we_hqpp_product_manager', menu_index=0, text='Add new product')

        cn8_code = self.sa_session.query(WeCN8).first()

        product_state = self.get_product_state(member.id, cn8_code.code, tbs_product_level.id)

        self.fill_form(panel_name='we_hqpp_product_panel', values={'sku': ('input_text', product_state['sku']),
                                                                   'product_name': ('input_text', product_state['product_name']),
                                                                   'cn8_codes': ('fancy-select', ["%s - %s" % (cn8_code.code, cn8_code.description)]),
                                                                   'weight_per_unit': ('input_text', product_state['weight_per_unit']),
                                                                   'length_per_unit': ('input_text', product_state['length_per_unit']),
                                                                   'width_per_unit': ('input_text', product_state['width_per_unit']),
                                                                   'height_per_unit': ('input_text', product_state['height_per_unit']),
                                                                   'weight_cat1': ('input_text', product_state['weight_cat1']),
                                                                   'weight_cat2': ('input_text', product_state['weight_cat2']),
                                                                   'weight_cat3': ('input_text', product_state['weight_cat3']),
                                                                   'weight_cat4': ('input_text', product_state['weight_cat4']),
                                                                   'weight_batteries': ('input_text', product_state['weight_batteries']),
                                                                   'weight_documentation': ('input_text', product_state['weight_documentation'])})

        # assert that saving without product levels selected raises error
        self.click_button(panel_name='we_hqpp_product_panel', text='Save and close')
        self.wait_for_loading(assert_no_errors=False)
        self.assert_growl_errors_present()

        import time
        time.sleep(5)

        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=0,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (tbs_product_level.label,
                                                                               tbs_product_level.description))})
        self.click_button(panel_name='we_hqpp_product_panel', text='Save and close')
        self.wait_for_loading(assert_no_errors=False)

        l = self.cq_rows_length(panel_name='we_hqpp_product_manager')
        self.assertEqual(l, 1)

        self.click_cq(panel_name='we_hqpp_product_manager', row_index=0, col_name='product_name')
        self.wait_for_loading(assert_no_errors=False)

        self.assert_form(panel_name='we_hqpp_product_panel', values={'sku': ('input_text', product_state['sku']),
                                                                   'product_name': ('input_text', product_state['product_name']),
                                                                   'cn8_codes': ('fancy-select', ["%s - %s" % (cn8_code.code, cn8_code.description)]),
                                                                   'weight_per_unit': ('input_text', '2.123'),
                                                                   'length_per_unit': ('input_text', '12.000'),
                                                                   'weight_cat1': ('input_text', '12.000'),
                                                                   'weight_cat2': ('input_text', '12.000')})

        self.click_growl('critical')  # make the error go away
        self.logout()

        tbs_account = self._create_tbs_account(tbs)
        self.login(tbs_account.name, 'test_password')

        self.click_iconbar('icon-we-hqpp-product-manager', hover='icon-we-member-manager')
        self.wait_for_loading()

        self.assert_cq('we_hqpp_product_manager', row_index=0, data={'product_name': product_state['product_name']})

    def test_product_sheet_as_member(self):
        """
        Test that an HQPP user sees only his own products
        """
        # add HQPP
        set_date(date(2015, 5, 5))
        member, lpp, tbs_product_level, tbs = self.create_lpp(member_account=True)
        self.member_account = member.default_group.accounts[0]
        self._attach_permissions_to_group(member.default_group, 'we_view_products', 'view_dashboard', 'we_view_tbs_product_level')

        categories = [{
            'id': tbs_product_level.id,
            'fee': Decimal('20.12')
        }]
        rp = self.create_tbs_regulation_period(tbs.id, self._uniquestring('RP'), 2015, 1, categories)

        code = self.sa_session.query(WeCN8).first()

        self.add_hqpp_product(member.id, tbs_product_level.id, code.code, 'WEE2312532')

        # add a second HQPP
        member1, lpp1, tbs_product_level1, tbs1 = self.create_lpp(member_account=True)
        self.member_account = member1.default_group.accounts[0]
        self._attach_permissions_to_group(member1.default_group, 'we_view_products', 'view_dashboard', 'we_view_tbs_product_level')

        categories = [{
            'id': tbs_product_level1.id,
            'fee': Decimal('20.12')
        }]
        rp1 = self.create_tbs_regulation_period(tbs1.id, self._uniquestring('RP'), 2015, 1, categories)

        code = self.sa_session.query(WeCN8).first()

        self.add_hqpp_product(member1.id, tbs_product_level1.id, code.code, 'RTU594932')

        self.login(self.member_account.name, 'abcd123456')

        self.click_iconbar('icon-we-hqpp-product-manager', 'icon-we-member-manager')
        self.wait_for_loading()

        # check that manager shows only 1 product
        l = self.cq_rows_length(panel_name='we_hqpp_product_manager')
        self.assertEqual(l, 1)

    def test_create_member_as_lpp(self):

        self.login(self._operator_account.name, 'test_password')

        self.click_iconbar('icon-we-member-wizard', hover='icon-we-member-manager')
        self.wait_for_loading()

        comp = self._uniquestring('c')
        # fill out the wizard company page.
        company_forms_data = {
            'company_form': {
                'name': comp,
                'website': 'http://member.com',
                'vat_no': 'RO1630615123457',
            },
            'address_form': {
                'street': 'Member Street',
                'street_2': 'Member Street 2',
                'city': 'Amsterdam',
                'postcode': '1000AA',
                'country': ('select', 'Belgium'),
                'state': 'NH'
            },
            'bank_account_form': {
                'number': "1234567890",
                'iban': "GB82WEST12345698765432",
                'bic': "UNCRIT2B912",
            }
        }

        self.fill_forms(panel_name='we-member-wizard', forms_data=company_forms_data)
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # contact/invoice person info
        person_forms_data = {
            'person_form': {
                'last_name': 'Member Contact Last Name',
                'first_name': 'Member Contact First Name',
                'email': 'test-member@mail-test.basesoft.com',
                'preferred_locale': ('select', 'English'),
                'gender': ('select', 'Male'),
                'phone': '234234235',
                'mobile_phone': '123412345',
            },
            'invoice_person_form': {
                'is_same_person_as': ('checkbox', 'true')
            }
        }
        self.fill_forms(panel_name='we-member-wizard', forms_data=person_forms_data)
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # create account info
        self.fill_forms(panel_name='we-member-wizard', forms_data={
            'skip_account': {
                'skip_account': ('checkbox', True),
            }
        })
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # select LPP option
        self.fill_form(panel_name='we-member-wizard', values={'lpp_selection': ('radio', 0)})
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # this is the Finish page. Just clicky button and company details should open up
        self.click_button(panel_name='we-member-wizard', text=u'Finish')
        self.wait_for_loading()

        # check company name and vat is the same
        self.assert_form(panel_name='we-company-details', form_name='company_form', values={'name': comp,
                                                                                       'vat_no': 'RO1630615123457'})
        # add TBS and save
        tbs = self._create_tbs(self._operator_account.id)

        self.click_button(panel_name='we-company-details', form_name='lpp_form', text='Add an additional row')

        # set that company as AR as well
        self.fill_form(panel_name='we-company-details', form_name='lpp_form', rowcontrol_row_index=0,
                       values={'tbs_id': ('select', tbs.name), 'use_as_ar': ('checkbox', True)})
        self.click_button(panel_name='we-company-details', text='Save')
        self.wait_for_loading()

        self.click_iconbar('icon-we-member-manager')
        self.wait_for_loading()

        self.filter_cq(panel_name='we-member-manager', filters=[('Producer', 'Equal', comp)])
        self.wait_for_loading()

        self.assert_cq(panel_name='we-member-manager', row_index=0, data={'member_name': comp, 'lpp': comp,
                                                                          'ar_company': comp})

    def test_add_company_to_tbs_panel(self):
        tbs = self._create_tbs(self._operator_account.id)
        member = self._create_member(self._operator_account.id)

        self.login(self._operator_account.name, 'test_password')

        self.click_iconbar('icon-we-member-manager')
        self.wait_for_loading()

        # find the member
        self.filter_cq(panel_name='we-member-manager', filters=[('Producer', 'Equal', member.name)])
        self.wait_for_loading()

        # click the row
        self.click_cq(panel_name='we-member-manager', row_index=0, col_name='row_select', extra_css=' input')

        # open panel to link LPP to TBS
        self.click_menu(panel_name='we-member-manager', menu_index=0, text='Add LPP to TBS')
        self.wait_for_loading()

        # select tbs first
        self.fill_form(panel_name='we-company-links-to-tbs', rowcontrol_row_index=0,
                       values={'tbs_id': ('autocomplete', tbs.name)})

        # companies should be in the same country as tbs
        self.fill_form(panel_name='we-company-links-to-tbs', rowcontrol_row_index=0,
                       values={'lpp_company_id': ('autocomplete', member.name),
                               'invoice_company_id': ('autocomplete', member.name),
                               'ar_company_id': ('autocomplete', member.name)})

        import time
        time.sleep(1)
        self.click_button(panel_name='we-company-links-to-tbs', text='Save and close')
        self.wait_for_loading()

        self.assert_cq(panel_name='we-member-manager', row_index=0, data={'member_name': member.name, 'lpp': member.name,
                                                                          'ar_company': member.name, 'invoice_company': member.name,
                                                                          'tbs': tbs.name})

    def test_create_non_eu_member(self):
        self._create_tbs(self._operator_account.id)

        self.login(self._operator_account.name, 'test_password')

        self.click_iconbar('icon-we-member-wizard', hover='icon-we-member-manager')
        self.wait_for_loading()

        comp = self._uniquestring('c')
        # fill out the wizard company page.
        company_forms_data = {
            'company_form': {
                'name': comp,
                'website': 'http://member.com',
                'vat_no': self.get_vat_numbers()[0]
            },
            'address_form': {
                'street': 'Member Street',
                'street_2': 'Member Street 2',
                'city': 'Amsterdam',
                'postcode': '1000AA',
                'country': ('select', 'Angola'),
                'state': 'NH'
            },
            'bank_account_form': {
                'number': "1234567890",
                'bank_name': "Goldman Sucks",
            },
            'bank_account_addressForm': {
                'street': 'BANK street 1',
                'postcode': 'bank0000',
                'city': 'Angola',
                'country': ('select', 'Angola'),
            }
        }

        self.fill_forms(panel_name='we-member-wizard', forms_data=company_forms_data)
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # contact/invoice person info
        person_forms_data = {
            'person_form': {
                'last_name': 'Member Contact Last Name',
                'first_name': 'Member Contact First Name',
                'email': 'test-member@mail-test.basesoft.com',
                'preferred_locale': ('select', 'English'),
                'gender': ('select', 'Male'),
                'phone': '234234235',
                'mobile_phone': '123412345',
            },
            'invoice_person_form': {
                'is_same_person_as': ('checkbox', 'true')
            }
        }
        self.fill_forms(panel_name='we-member-wizard', forms_data=person_forms_data)
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # create account info
        self.fill_forms(panel_name='we-member-wizard', forms_data={
            'account_details': {
                'account_name': ('input_text', self._uniquestring('Acc')[:10]),
            },
            'set_password_form': {
                'send_link': ('checkbox', True)
            },
            "account_person_form": {
                'last_name': 'MC Last Name',
                'first_name': 'MC First Name',
                'email': 'test-mc@test.basesoft.com',
                'preferred_locale': ('select', 'English'),
                'gender': ('select', 'Male'),
                'phone': '234234235',
                'mobile_phone': '123412345',
            }
        })
        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        self.click_button(panel_name='we-member-wizard', text=u'Next »')
        self.wait_for_loading()

        # this is the Finish page. Just clicky button
        self.click_button(panel_name='we-member-wizard', text=u'Finish')

        # open member manager
        self.click_iconbar('icon-we-member-manager')

        # check that we have a member saved
        self.filter_cq(panel_name='we-member-manager', filters=[('Producer', 'Equal', comp)])
        self.wait_for_loading()

        self.click_cq(panel_name='we-member-manager', row_index=0, col_name='member_name')
        self.wait_for_loading()

        self.assert_form(panel_name='we-member-details', form_name='bank_account_addressForm', values={
            'street': 'BANK street 1',
            'postcode': 'bank0000',
            'country': ('select', 'Angola')
        })

    def test_tbs_view_lpp_master_data(self):
        tbs = self._create_tbs(self._operator_account.id)
        master_data = self._get_member_state('a')
        controller = WeMemberController(self.sa_session, account_id=self._operator_account.id)
        member = controller.register_member(master_data, None)

        lpp_state = {
            'lpp': {
                'tbses': [{
                    'tbs_id': tbs.id,
                    'lpp_relation_id': 123,
                    'invoice_relation_id': 123,
                    'lpp_id': None,
                    'use_as_ar': False
                }],
                'member_id': member.id
            },
            'address_data': {'city': u'Boston', 'state': u'Indiana',
                             'street': u'West street', 'country_iso_3166_a2': u'AO',
                             'postcode': u'1132WD', 'country': 7L, 'country_name': u'Angola',
                             'street_2': None, 'country_iso_3166_a3': u'AGO'},
            'contact_person_data': {
                             'first_name': u'John', 'last_name': u'Doe', 'middle_name': u'van', 'polymorphic_type': u'Person',
                             'skype_name': u'BaronJohn', 'title': u'Baron', 'fax': u'123323456', 'phone': u'123456678',
                             'mobile_phone': u'003132435655', 'gender': u'male', 'birth_date': date(1978, 12, 12), 'position': u'Manager',
                             'department': u'IT', 'email': u'doe@john.com', 'preferred_locale': 1
            },
            'bank_data': {
                             'bank_name': u'BankCorp', 'beneficiary': u'What is this?',
                             'number': u'3838383838', 'bic': u'BIC123457',
                             'note': u'Its a note', 'iban': u'AO22BC390594389'
            },
            'website': u'http://wwww.basesoft.com/',
            'name': u'you down with lpp',
            'vat_no': u'RO1630615123457',
        }

        controller.save_or_update_company_details(None, lpp_state)

        tbs_account = self._create_tbs_account(tbs)
        self.login(tbs_account.name, 'test_password')

        self.click_iconbar('icon-we-lpp-master-data-manager', hover='icon-we-member-manager')
        self.wait_for_loading()

        self.assert_cq('we_lpp_master_data_manager', row_index=0, data={'lpp': 'you down with lpp'})

    def test_tbs_view_producer_manager(self):
        tbs = self._create_tbs(self._operator_account.id)
        master_data = self._get_member_state('a')
        controller = WeMemberController(self.sa_session, account_id=self._operator_account.id)
        member = controller.register_member(master_data, None)

        lpp_state = {
            'lpp': {
                'tbses': [{
                    'tbs_id': tbs.id,
                    'lpp_relation_id': 123,
                    'invoice_relation_id': 123,
                    'lpp_id': None,
                    'use_as_ar': False
                }],
                'member_id': member.id
            },
            'address_data': {'city': u'Boston', 'state': u'Indiana',
                             'street': u'West street', 'country_iso_3166_a2': u'AO',
                             'postcode': u'1132WD', 'country': 7L, 'country_name': u'Angola',
                             'street_2': None, 'country_iso_3166_a3': u'AGO'},
            'contact_person_data': {
                             'first_name': u'John', 'last_name': u'Doe', 'middle_name': u'van', 'polymorphic_type': u'Person',
                             'skype_name': u'BaronJohn', 'title': u'Baron', 'fax': u'123323456', 'phone': u'123456678',
                             'mobile_phone': u'003132435655', 'gender': u'male', 'birth_date': date(1978, 12, 12), 'position': u'Manager',
                             'department': u'IT', 'email': u'doe@john.com', 'preferred_locale': 1
            },
            'bank_data': {
                             'bank_name': u'BankCorp', 'beneficiary': u'What is this?',
                             'number': u'3838383838', 'bic': u'BIC123457',
                             'note': u'Its a note', 'iban': u'AO22BC390594389'
            },
            'website': u'http://wwww.basesoft.com/',
            'name': u'you down with lpp',
            'vat_no': u'RO1630615123457',
        }

        controller.save_or_update_company_details(None, lpp_state)

        tbs_account = self._create_tbs_account(tbs)
        self.login(tbs_account.name, 'test_password')

        self.click_iconbar('icon-we-member-manager')
        self.wait_for_loading()

        self.assert_cq('we-member-manager', row_index=0, data={'member_name': member.name})

    def test_member_index_widget(self):
        # login as TBS user and check if we can view this declaration
        member, lpp, tbs_product_level, tbs = self.create_lpp(member_account=True)
        member_account = member.default_group.accounts[0]
        self.login(member_account.name, 'abcd123456')

        self.expand_layout_pane(0)
        self.click_palette('Mode')
        self.click_palette('Compose')
        self.wait_for_loading()

        self.click_palette('Navigation', palette_index=2)

        # drag widgy
        self.drag_item_from_palette('Navigation widget', block_index=0, column_index=0)
        self.wait_for_loading()
