# -*- coding: utf-8 -*-

'''
Created on Jan 7, 2015

@author: rado
'''
import os

from datetime import date
from decimal import Decimal
from basesoft.web.contrib.scheduler.controllers import SchedulerServerController
from sqlalchemy.sql.expression import and_

from selenium.common.exceptions import NoSuchElementException
from selenium.webdriver.support.select import Select

from basesoft.util.virtual_date import set_date, today

from we.core.controllers import WeCoreController
from we.product.controllers import WeProductController
from we.product import schedule
from we.tbs.models import WeTbsRegulationPeriod
from we.test.selenium.we_selenium import WeSeleniumTestCase
from we.product.models import WeCN8, WeTbsProductLevel, WeHqppProduct, WeHqppRegulationPeriodProduct, \
    WeTbsRegulationPeriodProduct


class TestCase(WeSeleniumTestCase):
    def setUp(self):
        super(TestCase, self).setUp()

        self.connect_db()

        self._operator_account = self._create_operator_account()

    def test_match_cn8_to_weee_product_level(self):
        """
        First add a new CN8 from the panel then use it for matching to WEEE product level
        :return:
        """
        # clear any existing matches
        codes = self.sa_session.query(WeCN8).filter(WeCN8.weee_product_level_id != None).all()
        for code in codes:
            code.unu_code = None
            code.weee_product_level = None
            self.sa_session.add(code)
        self.sa_session.flush()

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open cn8 code manager
        self.click_iconbar('icon-we-cn8-we-product-level-manager', 'icon-we-product-level-manager')
        self.wait_for_loading()

        # open panel add/update cn8
        self.click_menu('we-cn8-we-product-level-manager', menu_index=1, text='Add/Update CN8 code')
        self.wait_for_loading()

        # add new code
        self.fill_form(panel_name='we-cn8-code-panel', values={
            'cn8_code': ('input_text', 44444444),
            'cn8_description': ('input_text', 'Test CN8 description')
        })
        self.click_button(panel_name='we-cn8-code-panel', text='Save and close')
        self.wait_for_loading()

        # create new cn8 to subcategory match from manager menu
        self.click_menu('we-cn8-we-product-level-manager', menu_index=1, text='Match CN8 code to WEEE category')
        self.wait_for_loading()

        # test fancy select filter
        self.fill_form(panel_name='we-cn8-we-product-level-details', form_name='cn8-to-product-level', values={'search-filter': 49051000})
        self.wait_for_loading()

        # check that fancy select has only 1 option
        select = self.get_form_element(panel_name='we-cn8-we-product-level-details', form_name='cn8-to-product-level',
                                       values={'cn8_codes': ('fancy-select', [''])})
        left_select = Select(select)
        self.assertEqual(len(left_select.options), 1)

        # clear the filter
        self.fill_form(panel_name='we-cn8-we-product-level-details', form_name='cn8-to-product-level', values={'search-filter': ''})
        self.wait_for_loading()

        # create a cn8 to category match, use the added CN8
        values = {
            'weee_product_level_id': ('select', 'EEE-1.01.03 - Freezers'),
            'unu_code': ('select', '0111'),
            'cn8_codes': ('fancy-select', ["44444444 - Test CN8 description",
                                           "63011000 - Electric blankets of all types of textile materials"])
        }
        self.fill_form(panel_name='we-cn8-we-product-level-details', form_name='cn8-to-product-level', values=values)
        # clicking 'Save and next' should refresh the panel
        self.click_button(panel_name='we-cn8-we-product-level-details', text='Save and next')
        self.wait_for_loading()

        # select CN8 codes and WEEE category
        values = {
            'weee_product_level_id': ('select', 'EEE-1.01.02 - Refrigerators'),
            'unu_code': ('select', '0108'),
            'cn8_codes': ('fancy-select', ["84021100 - Watertube boilers with a steam production > 45 t/hour",
                                           "84022000 - Superheated water boilers"])
        }
        self.fill_form(panel_name='we-cn8-we-product-level-details', form_name='cn8-to-product-level', values=values)
        self.click_button(panel_name='we-cn8-we-product-level-details', text='Save and close')
        self.wait_for_loading()

        # filter by category
        self.filter_cq(panel_name='we-cn8-we-product-level-manager', filters=[('WEEE product category', 'Contains', 'EEE-1.01.02')])
        self.wait_for_loading()

        # separate CQ
        self.click_toolbar_button('we-cn8-we-product-level-manager', 'separate')
        self.wait_for_loading()

        # assert first cn8 code and that cq has 2 rows
        self.assert_cq(panel_name='we-cn8-we-product-level-manager', row_index=0, data={'cn8': str(84021100), 'unu_code': '0108'})
        cq_length = self.cq_rows_length(panel_name='we-cn8-we-product-level-manager', is_datatable=True)
        self.assertEqual(cq_length, 2)

        # select the row in the cq and delete from menu
        self.click_cq(panel_name='we-cn8-we-product-level-manager', row_index=0, col_name='row_select', extra_css=' input')
        self.click_menu(panel_name='we-cn8-we-product-level-manager', menu_index=1, text='Delete CN8 code matches')

        # wait for deletion to be finished
        import time
        time.sleep(2)

        # check that the matched subcategory is removed from the CN8
        code = self.sa_session.query(WeCN8).filter(WeCN8.code == 84021100).one()
        self.assertEqual(code.weee_product_level_id, None)

        # test loading a match, click on subcategory
        self.click_cq(panel_name='we-cn8-we-product-level-manager', row_index=0, col_name='weee_product_level')
        self.wait_for_loading(assert_no_errors=False)

        # assert form values
        values = {
            'weee_product_level_id': ('select', 'EEE-1.01.02 - Refrigerators'),
            'unu_code': ('select', '0108'),
            'cn8_codes': ('fancy-select', ["84022000 - Superheated water boilers"])
        }
        self.assert_form(panel_name='we-cn8-we-product-level-details', form_name='cn8-to-product-level', values=values)

        # Overwrite record
        self.fill_form(panel_name='we-cn8-we-product-level-details', form_name='cn8-to-product-level',
                       values={'weee_product_level_id': ('select', 'EEE-1.01.03 - Freezers')})
        self.click_button(panel_name='we-cn8-we-product-level-details', text='Save and close')
        self.wait_for_loading(assert_no_errors=False)

        # confirm Overwrite
        self.click_button(panel_name='dialog-question', text='Yes')
        self.wait_for_loading(assert_no_errors=False)

        # cn8 should be linked to product_level_id = 5
        code = self.sa_session.query(WeCN8).filter(WeCN8.code == 84022000).one()
        self.assertEqual(code.weee_product_level_id, 5)

    def test_create_tbs_product_level(self):
        tbs = self._create_tbs(self._operator_account.id)

        product_level1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level2, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level3, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        categories = [{
            'id': product_level1.id,
            'fee': Decimal('20.12')
        },{
            'id': product_level2.id,
            'fee': Decimal('33.33')
        },{
            'id': product_level3.id,
            'fee': Decimal('12.45')
        }]
        rp = self.create_tbs_regulation_period(tbs.id, 'Test RP', 2015, 1, categories)

        tbs.set_config('we.tbs.use.negative.fee', True)

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open local category manager
        self.click_iconbar('icon-we-tbs-price-sheet-manager', 'icon-we-tbs-manager')

        # open TBS local category panel
        self.click_menu('we-tbs-price-sheet-manager', menu_index=1, text='Add new take-back scheme local category')
        self.wait_for_loading()

        self.fill_form(panel_name='we-tbs-product-level-details',
                       values={'tbs_id': ('select', 'value=%s' % tbs.id)})
        self.wait_for_loading()

        self.fill_form(panel_name='we-tbs-product-level-details',
                       values={'tbs_regulation_period_id': ('select', rp.title)})
        self.wait_for_loading()

        self.fill_form(panel_name='we-tbs-product-level-details',
                       values={'parent_level_id': ('select', '%s - %s' % (product_level1.label,
                                                                          product_level1.description))})

        self.fill_form(panel_name='we-tbs-product-level-details',
                       values={'label': ('input_text', 'Category label'),
                               'description': ('input_text', 'Test DESCRIPTION'),
                               'invoice_basis': ('select', 'Weight'),
                               'fee': Decimal('-2.22')})

        self.click_button(panel_name='we-tbs-product-level-details', text='Save')
        self.wait_for_loading()

        # assert data is in the cq
        self.filter_cq(panel_name='we-tbs-price-sheet-manager', filters=[
            ('Tbs', 'Contains', tbs.name),
            ('Category label', 'Equal', 'Category label')
        ])

        rows = self.cq_rows_length(panel_name='we-tbs-price-sheet-manager')
        self.assertEqual(rows, 1)

        self.assert_cq(panel_name='we-tbs-price-sheet-manager', row_index=0,
                       data={'fee': '-2.22000', 'regulation_period_start_date': '01/01/2015'})

    def test_change_parent_of_product_level(self):
        set_date(date(2015, 5, 5))
        tbs = self._create_tbs(self._operator_account.id)

        # create two main levels
        main_level, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        # create one sub_level
        sub_level, tbs = self.create_tbs_product_level(self._operator_account.id, tbs, None, parent_level_id=main_level.id)

        categories = [{
            'id': main_level.id,
            'fee': Decimal('20.12')
        },{
            'id': product_level1.id,
            'fee': Decimal('33.33')
        },{
            'id': sub_level.id,
            'fee': Decimal('12.45')
        }]
        rp = self.create_tbs_regulation_period(tbs.id, 'Test RP', 2015, 1, categories)

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open local category manager
        self.click_iconbar('icon-we-tbs-price-sheet-manager', 'icon-we-tbs-manager')

        # filter manager to get the sub-level
        self.filter_cq(panel_name='we-tbs-price-sheet-manager', filters=[('Category label', 'Contains', sub_level.label)])
        self.wait_for_loading()

        # click on the label to open details
        self.click_cq(panel_name='we-tbs-price-sheet-manager', row_index=0, col_name='tbs_pl_label')
        self.wait_for_loading()

        # change parent level
        self.fill_form(panel_name='we-tbs-product-level-details',
                       values={'parent_level_id': ('select', '%s - %s' % (product_level1.label,
                                                                          product_level1.description))})

        # save
        self.click_button(panel_name='we-tbs-product-level-details', text='Save')
        self.wait_for_loading()

        # open details again
        self.click_cq(panel_name='we-tbs-price-sheet-manager', row_index=0, col_name='tbs_pl_label')
        self.wait_for_loading()

        # assert parent level is saved
        self.assert_form(panel_name='we-tbs-product-level-details',
                         values={'parent_level_id': ('select', '%s - %s' % (product_level1.label,
                                                                            product_level1.description))})

    def test_import_cn8_codes(self):
        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open cn8 code manager
        self.click_iconbar('icon-we-cn8-we-product-level-manager', 'icon-we-product-level-manager')

        # open panel for file upload
        self.click_menu('we-cn8-we-product-level-manager', menu_index=1, text='Import CN8 to WEEE category file')
        self.wait_for_loading()

        file_path = os.path.join(os.path.dirname(__file__), os.pardir, 'files', 'test_cn8.csv')

        self.fill_form(panel_name='cn8-code-upload', values={
            'upload_cn8': ('upload', file_path),
        })

        self.click_button(panel_name='cn8-code-upload', text='Submit')
        self.assert_no_growl_errors()

        # find code in manager and assert row
        self.filter_cq(panel_name='we-cn8-we-product-level-manager', filters=[('CN8', 'Contains', '88888888')])
        self.wait_for_loading()

        self.assert_cq(panel_name='we-cn8-we-product-level-manager', row_index=0, data={'cn8': '88888888',
                                                                                        'weee_product_level': 'EEE-1.01.01',
                                                                                        'unu_code': '0444'})

    def test_product_sheet_details_is_b2b(self):
        # add HQPP
        member, lpp, tbs_product_level, tbs = self.create_lpp()
        pl1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        pl2, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        code = self.sa_session.query(WeCN8).first()

        # create tbs regulation period
        rp_name = self._uniquestring('RP_')
        self.create_tbs_regulation_period(tbs.id, rp_name, 2015, 1,
                                          [{'id': tbs_product_level.id, 'fee': Decimal('2.22')},
                                           {'id': pl1.id, 'fee': Decimal('0.11')},
                                           {'id': pl2.id, 'fee': Decimal('11.11')}])
        set_date(date(2015, 8, 1))

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open local category manager
        self.click_iconbar('icon-we-hqpp-product-manager', 'icon-we-member-manager')
        self.wait_for_loading()

        # open panel for adding products
        self.click_menu('we_hqpp_product_manager', menu_index=1, text='Add new product')
        self.wait_for_loading()

        values = {
            'hqpp_id': ('select', member.name),
            'sku': self._uniquestring('SKU_')[:15],
            'product_name': 'NEW PRODUCT',
            'weight_per_unit': Decimal('2.221'),
            'cn8_codes': ('fancy-select', ['%s - %s' % (code.code, code.description)])
        }
        self.fill_form(panel_name='we_hqpp_product_panel', values=values)
        self.wait_for_loading()

        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=0,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (tbs_product_level.label,
                                                                               tbs_product_level.description))})

        self.click_button(panel_name='we_hqpp_product_panel', text='Save and close')
        self.wait_for_loading()

        # find the record
        self.filter_cq('we_hqpp_product_manager', filters=[('SKU code', 'Contains', values['sku'])])
        self.wait_for_loading()

        # assert it's only 1 row
        rows = self.cq_rows_length('we_hqpp_product_manager')
        self.assertEqual(rows, 1)
        self.assert_cq('we_hqpp_product_manager', row_index=0, data={'b2b-b2c': u' '})

        # enable b2b for TBS
        tbs.set_config('we.tbs.require.end.user.distinction', True)

        # load the saved record
        self.click_cq('we_hqpp_product_manager', row_index=0, col_name='product_name')
        self.wait_for_loading()

        # fill in  the rows
        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=0,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (pl2.label, pl2.description))})

        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=1,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (pl1.label, pl1.description))})

        self.click_button(panel_name='we_hqpp_product_panel', text='Save and close')
        self.wait_for_loading()

        # assert manager shows the new rows
        rows = self.cq_rows_length('we_hqpp_product_manager')
        self.assertEqual(rows, 3)

        # disable the second link
        self.click_cq('we_hqpp_product_manager', row_index=0, col_name='product_name')
        self.wait_for_loading()

        # fill in  the rows
        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=1,
                       values={'tbs_product_level_id': ('select', '-')})

        self.click_button(panel_name='we_hqpp_product_panel', text='Save and close')
        self.wait_for_loading()

        self.assert_cq('we_hqpp_product_manager', row_index=1, data={'tbs_regulation_period': rp_name})

    def test_product_sheet_details_save_again(self):
        # add HQPP
        member, lpp, tbs_product_level, tbs = self.create_lpp()
        pl1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        pl2, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        code = self.sa_session.query(WeCN8).first()

        # create tbs regulation period
        rp_name = self._uniquestring('RP_')
        self.create_tbs_regulation_period(tbs.id, rp_name, 2015, 1,
                                          [{'id': tbs_product_level.id, 'fee': Decimal('2.22')},
                                           {'id': pl1.id, 'fee': Decimal('0.11')},
                                           {'id': pl2.id, 'fee': Decimal('11.11')}])
        set_date(date(2015, 8, 1))

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open local category manager
        self.click_iconbar('icon-we-hqpp-product-manager', 'icon-we-member-manager')
        self.wait_for_loading()

        # open panel for adding products
        self.click_menu('we_hqpp_product_manager', menu_index=1, text='Add new product')
        self.wait_for_loading()

        values = {
            'hqpp_id': ('select', member.name),
            'sku': self._uniquestring('SKU_')[:15],
            'product_name': 'NEW PRODUCT',
            'weight_per_unit': Decimal('2.221'),
            'cn8_codes': ('fancy-select', ['%s - %s' % (code.code, code.description)])
        }
        self.fill_form(panel_name='we_hqpp_product_panel', values=values)
        self.wait_for_loading()

        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=0,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (tbs_product_level.label,
                                                                               tbs_product_level.description))})

        self.click_button(panel_name='we_hqpp_product_panel', text='Save')
        self.wait_for_loading()

        self.click_button(panel_name='we_hqpp_product_panel', text='Save and close')
        self.assert_no_growl_errors()
        self.wait_for_loading()

        # find the record
        self.filter_cq('we_hqpp_product_manager', filters=[('SKU code', 'Contains', values['sku'])])
        self.wait_for_loading()

        # assert it's only 1 row
        rows = self.cq_rows_length('we_hqpp_product_manager')
        self.assertEqual(rows, 1)
        self.assert_cq('we_hqpp_product_manager', row_index=0, data={'b2b-b2c': u' '})

        # enable b2b for TBS
        tbs.set_config('we.tbs.require.end.user.distinction', True)

        # load the saved record
        self.click_cq('we_hqpp_product_manager', row_index=0, col_name='product_name')
        self.wait_for_loading()

        # fill in  the rows
        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=0,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (pl2.label, pl2.description))})

        self.fill_form(panel_name='we_hqpp_product_panel', rowcontrol_row_index=1,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (pl1.label, pl1.description))})

        self.click_button(panel_name='we_hqpp_product_panel', text='Save')
        self.wait_for_loading()

        self.click_button(panel_name='we_hqpp_product_panel', text='Save')
        self.assert_no_growl_errors()

    def test_import_product_sheet(self):

        SchedulerServerController().enable_task('we.product.schedule.HqppProductSheetTask')

        set_date(date(2015, 5, 5))
        f_name, member, tbses, rps = self.create_product_sheet_csv_file()

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open cn8 code manager
        self.click_iconbar('icon-we-hqpp-product-manager', 'icon-we-member-manager')

        # open panel for file upload
        self.click_menu('we_hqpp_product_manager', menu_index=1, text='Import product sheet')
        self.wait_for_loading()

        # select hqpp
        self.fill_form(panel_name='hqpp-product-sheet-import', values={
            'hqpp_id': ('select', member.name),
        })
        self.wait_for_loading()

        # select regulation periods
        self.fill_form(panel_name='hqpp-product-sheet-import', rowcontrol_row_index=0,
                       values={'tbs_regulation_period_id': ('select', rps[0].title)})
        self.fill_form(panel_name='hqpp-product-sheet-import', rowcontrol_row_index=1,
                       values={'tbs_regulation_period_id': ('select', rps[1].title)})
        self.fill_form(panel_name='hqpp-product-sheet-import', rowcontrol_row_index=2,
                       values={'tbs_regulation_period_id': ('select', rps[2].title)})
        self.fill_form(panel_name='hqpp-product-sheet-import', rowcontrol_row_index=3,
                       values={'tbs_regulation_period_id': ('select', rps[3].title)})
        import os
        path = os.path.abspath(f_name)
        # select file
        self.fill_form(panel_name='hqpp-product-sheet-import', values={
            'upload_products': ('upload', path),
        })

        self.click_button(panel_name='hqpp-product-sheet-import', text='Submit')
        self.wait_for_loading()

        product = self.sa_session.query(WeHqppProduct).filter(and_(WeHqppProduct.sku == '210-344',
                                                                   WeHqppProduct.hqpp == member)).one()
        # get linked tbs category
        links = self.sa_session.query(WeHqppRegulationPeriodProduct)\
            .filter(WeHqppRegulationPeriodProduct.product_id == product.id).all()
        self.assertEqual(len(links), 4)

        local_cats = ['11010', '3.1', '11030', '3.2']
        tbs_cats = [c.tbs_regulation_period_product.tbs_product_level.label for c in links]
        self.assertTrue(all(val in tbs_cats for val in local_cats))

        import os
        os.remove(f_name)

        cn8_codes = self.sa_session.query(WeCN8).limit(4).all()
        set_date(date(2015, 11, 1))
        headers = ['sku','name','description','is_b2b','cn8','weight_per_unit','length_per_unit','height_per_unit',
                   'width_per_unit','diagonal','weight_cat1','weight_cat2','weight_cat3','weight_cat4','weight_documentation',
                   'weight_batteries','weight_package','tbs-4','tbs-%s' % tbses[0].id, 'tbs-%s' % tbses[1].id, 'tbs-%s' % tbses[2].id,
                   'tbs-%s' % tbses[3].id, 'tbs-9','tbs-10','tbs-11','tbs-12']
        row1 = ['210-344','SKU1','','B2B',cn8_codes[0].code,'1.32','','999.999','','1000','','','','','','','','','11020','','','3.2','','','','']
        row2 = ['210-344','SKU1','','B2C',cn8_codes[0].code,'1.32','','999.999','','1000','','','','','','','','','11011','','','4.2','','','','']
        row3 = ['210-296','SKU3','','',cn8_codes[1].code,'3.837','','','','','','','','','','','','','','4.1.2','','','','','','']
        row4 = ['210-30','SKU4','','',cn8_codes[2].code,'2.283','','','','','','','','','','','','','','4.1.3','','','','','','']
        row5 = ['BG2036','SKU5','','',cn8_codes[3].code,'0.109','17.5','5.2','','','','','','','','','','','','','2/C06','','','','','']

        import openpyxl.workbook as workbook
        book = workbook.Workbook()
        sheet1 = book.get_active_sheet()
        sheet1.append(headers)
        sheet1.append(headers)
        sheet1.append(row1)
        sheet1.append(row2)
        sheet1.append(row3)
        sheet1.append(row4)
        sheet1.append(row5)
        book.save('test_product_sheet_xlsx.xlsx')

        # open panel for file upload
        self.click_menu('we_hqpp_product_manager', menu_index=1, text='Import product sheet')
        self.wait_for_loading()

        # select hqpp
        self.fill_form(panel_name='hqpp-product-sheet-import', values={
            'hqpp_id': ('select', member.name),
        })
        self.wait_for_loading()

        # select regulation periods
        self.fill_form(panel_name='hqpp-product-sheet-import', rowcontrol_row_index=0,
                       values={'tbs_regulation_period_id': ('select', rps[0].title)})
        self.fill_form(panel_name='hqpp-product-sheet-import', rowcontrol_row_index=1,
                       values={'tbs_regulation_period_id': ('select', rps[1].title)})
        self.fill_form(panel_name='hqpp-product-sheet-import', rowcontrol_row_index=2,
                       values={'tbs_regulation_period_id': ('select', rps[2].title)})
        self.fill_form(panel_name='hqpp-product-sheet-import', rowcontrol_row_index=3,
                       values={'tbs_regulation_period_id': ('select', rps[3].title)})

        path = os.path.abspath('test_product_sheet_xlsx.xlsx')
        # select file
        self.fill_form(panel_name='hqpp-product-sheet-import', values={
            'upload_products': ('upload', path),
        })

        self.click_button(panel_name='hqpp-product-sheet-import', text='Submit')
        self.wait_for_loading()

        # check that SKU has same local category as in the file
        product = self.sa_session.query(WeHqppProduct).filter(and_(WeHqppProduct.sku == '210-344',
                                                                   WeHqppProduct.hqpp == member)).one()
        # get linked tbs category
        links = self.sa_session.query(WeHqppRegulationPeriodProduct)\
            .filter(WeHqppRegulationPeriodProduct.product_id == product.id).all()
        self.assertEqual(len(links), 4)

        local_cats = ['11020', '3.2', '11011', '4.2']
        tbs_cats = [c.tbs_regulation_period_product.tbs_product_level.label for c in links]
        self.assertTrue(all(val in tbs_cats for val in local_cats))

        os.remove('test_product_sheet_xlsx.xlsx')

    def test_import_tbs_price_sheet(self):

        SchedulerServerController().enable_task('we.product.schedule.TbsPriceSheetImportTask')

        set_date(date(2015, 5, 1))
        tbs = self._create_tbs(self._operator_account.id)

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open tbs product level manager
        self.click_iconbar('icon-we-tbs-price-sheet-manager', 'icon-we-tbs-manager')

        # open panel for file upload
        self.click_menu('we-tbs-price-sheet-manager', menu_index=1, text='Import price sheet for new regulation period')
        self.wait_for_loading()

        # select tbs
        self.fill_form(panel_name='tbs-price-sheet-import-new', values={
            'tbs_id': ('select', tbs.name),
        })
        self.wait_for_loading2()

        self.fill_form(panel_name='tbs-price-sheet-import-new', values={
            'regulation_label': 'Test new RP selenium',
            'regulation_year': 2015,
        })
        self.wait_for_loading()

        self.fill_form(panel_name='tbs-price-sheet-import-new', values={
            'regulation_month': ('select', 'April'),
        })

        file_path = os.path.join(os.path.dirname(__file__), os.pardir, 'files', 'local_category_test_import.xlsx')
        # select file
        self.fill_form(panel_name='tbs-price-sheet-import-new', values={
            'upload_price_sheet_new': ('upload', file_path),
        })

        self.click_button(panel_name='tbs-price-sheet-import-new', text='Submit')
        self.wait_for_loading()

        # check that all categories are imported
        rp = self.sa_session.query(WeTbsRegulationPeriod)\
            .filter(and_(WeTbsRegulationPeriod.start_date == date(2015, 4, 1),
                         WeTbsRegulationPeriod.tbs == tbs)).one()
        levels = self.sa_session.query(WeTbsProductLevel).filter(WeTbsProductLevel.tbs == tbs).all()
        self.assertEqual(len(levels), 24)
        self.assertEqual(len(levels[1].sublevels), 5)
        self.assertEqual(levels[1].sublevels[0].label, '25010')
        self.assertEqual(levels[1].sublevels[0].invoice_basis, WeTbsProductLevel.INVOICE_BASED_ON_WEIGHT)
        self.assertEqual(levels[1].sublevels[0].get_current_regulation_period_product(rp.id).fee, Decimal('0.20000'))

        # update the regulation period
        # open panel for file upload
        self.click_menu('we-tbs-price-sheet-manager', menu_index=1, text='Import price sheet to update regulation period')
        self.wait_for_loading()

        # select tbs
        self.fill_form(panel_name='tbs-price-sheet-import-update', values={
            'tbs_id': ('select', tbs.name),
        })
        self.wait_for_loading()

        self.fill_form(panel_name='tbs-price-sheet-import-update', values={
            'regulation_period_id': ('select', rp.title),
        })

        file_path = os.path.join(os.path.dirname(__file__), os.pardir, 'files', 'local_category_test_import_update.xlsx')
        # select file
        self.fill_form(panel_name='tbs-price-sheet-import-update', values={
            'upload_price_sheet_update': ('upload', file_path),
        })

        self.click_button(panel_name='tbs-price-sheet-import-update', text='Submit')
        self.wait_for_loading()

        level = self.sa_session.query(WeTbsProductLevel).filter(and_(WeTbsProductLevel.tbs == tbs,
                                                                     WeTbsProductLevel.label == '11010')).one()
        self.assertEqual(level.get_current_regulation_period_product(rp.id).fee, Decimal('0.88000'))

    def test_import_tbs_product_levels_with_failures(self):

        SchedulerServerController().enable_task('we.product.schedule.TbsPriceSheetImportTask')

        tbs = self._create_tbs(self._operator_account.id)

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open tbs product level manager
        self.click_iconbar('icon-we-tbs-price-sheet-manager', 'icon-we-tbs-manager')

        # open panel for file upload
        self.click_menu('we-tbs-price-sheet-manager', menu_index=1, text='Import price sheet for new regulation period')
        self.wait_for_loading()

        # select tbs
        self.fill_form(panel_name='tbs-price-sheet-import-new', values={
            'tbs_id': ('select', tbs.name),
        })
        self.wait_for_loading2()

        self.fill_form(panel_name='tbs-price-sheet-import-new', values={
            'regulation_label': 'Test new RP selenium',
            'regulation_year': 2015,
        })
        self.wait_for_loading()

        self.fill_form(panel_name='tbs-price-sheet-import-new', values={
            'regulation_month': ('select', 'April'),
        })

        file_path = os.path.join(os.path.dirname(__file__), os.pardir, 'files', 'local_category_test_failures.xlsx')
        # select file
        self.fill_form(panel_name='tbs-price-sheet-import-new', values={
            'upload_price_sheet_new': ('upload', file_path),
        })

        self.click_button(panel_name='tbs-price-sheet-import-new', text='Submit')
        self.wait_for_loading()

        # check that there is a table with 4 lines failed
        # FIXME, after IQPORTAL #5029

    def test_import_cn8_to_tbs_product_level_file(self):
        SchedulerServerController().enable_task('we.product.schedule.CN8ToTbsProductLevelTask')

        tbs = self._create_tbs(self._operator_account.id)
        rp = self.create_tbs_regulation_period(tbs.id, 'rp', 2014, 1, [], 1)

        # login with account
        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # open tbs product level manager
        self.click_iconbar('icon-we-cn8-tbs-product-level-manager', 'icon-we-tbs-manager')

        # open panel for file upload
        self.click_menu('we_cn8_tbs_product_level_manager', menu_index=1, text='Import CN8 to local category file')
        self.wait_for_loading()

        # select tbs
        self.fill_form(panel_name='we-cn8-to-tbs-product-level-import', values={
            'tbs_id': ('select', tbs.name),
        })
        self.wait_for_loading()

        self.fill_form(panel_name='we-cn8-to-tbs-product-level-import', values={
            'regulation_period_id': ('select', 'value=%d' % rp.id),
        })

        file_path = os.path.join(os.path.dirname(__file__), os.pardir, 'files', 'cn8_to_local_category.csv')
        # select file
        self.fill_form(panel_name='we-cn8-to-tbs-product-level-import', values={
            'upload_file': ('upload', file_path),
        })
        self.wait_for_loading()

        self.click_button(panel_name='we-cn8-to-tbs-product-level-import', text='Submit')
        self.wait_for_loading()
        self.assert_no_growl_errors()

        # open panel with failure files
        # add the cn8 codes and the local categories
        codes = [11111111, 22222222, 33333333, 44445555]
        for code in codes:
            cn8 = self.sa_session.query(WeCN8).filter(WeCN8.code == code).first()
            if cn8 is not None:
                continue
            cn8 = WeCN8()
            cn8.code = code
            cn8.description = 'Test suggestion import'
            self.sa_session.add(cn8)
        self.sa_session.flush()

        pl1, bitbucket = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='11010')
        pl2, bitbucket = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='11011')
        pl3, bitbucket = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='11020')
        pl4, bitbucket = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='11030')
        pl5, bitbucket = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='45030')
        pl6, bitbucket = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='25040')

        pc = WeProductController(self.sa_session, account_id=self._operator_account.id)
        pc.save_or_update_regulation_period(rp.id, tbs.id, 'same same', 2014, 1, 1, [{
            'id': pl1.id,
            'fee': Decimal('12.345')
        },{
            'id': pl2.id,
            'fee': Decimal('1.002')
        },{
            'id': pl3.id,
            'fee': Decimal('0.56')
        },{
            'id': pl4.id,
            'fee': Decimal('12.345')
        },{
            'id': pl5.id,
            'fee': Decimal('1.002')
        },{
            'id': pl6.id,
            'fee': Decimal('0.56')
        }])

        self.close_panel(panel_name='we-product-file-import-manager')

        # open panel for file upload
        self.click_menu('we_cn8_tbs_product_level_manager', menu_index=1, text='Import CN8 to local category file')
        self.wait_for_loading()

        # select tbs
        self.fill_form(panel_name='we-cn8-to-tbs-product-level-import', values={
            'tbs_id': ('select', tbs.name),
        })
        self.wait_for_loading()

        self.fill_form(panel_name='we-cn8-to-tbs-product-level-import', values={
            'regulation_period_id': ('select', 'value=%d' % rp.id),
        })

        # import again
        file_path = os.path.join(os.path.dirname(__file__), os.pardir, 'files', 'cn8_to_local_category.csv')
        # select file
        self.fill_form(panel_name='we-cn8-to-tbs-product-level-import', values={
            'upload_file': ('upload', file_path),
        })
        self.wait_for_loading()

        self.click_button(panel_name='we-cn8-to-tbs-product-level-import', text='Submit')
        self.wait_for_loading()

    def test_regulation_period_creation(self):

        tbs = self._create_tbs(self._operator_account.id)
        product_level1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level2, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level3, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        self.click_iconbar('icon-we-tbs-price-sheet-manager', 'icon-we-tbs-manager')

        # open TBS local category panel
        self.click_menu('we-tbs-price-sheet-manager', text='New regulation period')
        self.wait_for_loading()

        self.fill_form(panel_name='we-tbs-regulation-period-details', values={
            'tbs_id': ('select', 'value=%d' % tbs.id)
        })
        self.wait_for_loading()  # product levels
        self.fill_form(panel_name='we-tbs-regulation-period-details', values={
            'label': 'My regulation period, period.',
            'start_year': '2015',
            'start_month': ('select', 'value=1'),
            'tbs_product_levels': ('fancy-select', [
                '%s - %s' % (product_level1.label, product_level1.description),
                '%s - %s' % (product_level3.label, product_level3.description)
            ])
        })
        self.wait_for_loading()

        self.fill_form(panel_name='we-tbs-regulation-period-details', values={
            'fee_%d' % product_level1.id: '-12.34',
            'fee_%d' % product_level3.id: '9.876',
        })

        # assert the fee value has no sign
        self.assert_form(panel_name='we-tbs-regulation-period-details', values={
            'fee_%d' % product_level1.id: '12.34',
            'fee_%d' % product_level3.id: '9.876',
        })

        tbs.set_config('we.tbs.use.negative.fee', True)

        # reload the panel and add the period with a negative fee
        self.click_button(panel_name='we-tbs-regulation-period-details', text='Cancel')

        self.click_menu('we-tbs-price-sheet-manager', text='New regulation period')
        self.wait_for_loading()

        self.fill_form(panel_name='we-tbs-regulation-period-details', values={
            'tbs_id': ('select', 'value=%d' % tbs.id)
        })
        self.wait_for_loading()  # product levels
        self.fill_form(panel_name='we-tbs-regulation-period-details', values={
            'label': 'My regulation period, period.',
            'start_year': '2015',
            'start_month': ('select', 'value=1'),
            'tbs_product_levels': ('fancy-select', [
                '%s - %s' % (product_level1.label, product_level1.description),
                '%s - %s' % (product_level3.label, product_level3.description)
            ])
        })
        self.wait_for_loading()

        self.fill_form(panel_name='we-tbs-regulation-period-details', values={
            'fee_%d' % product_level1.id: '-12.34',
            'fee_%d' % product_level3.id: '9.876',
        })
        self.click_button(panel_name='we-tbs-regulation-period-details', text='Save')
        self.wait_for_loading()

        pc = WeProductController(self.sa_session, account_id=self._operator_account.id)
        periods = pc.get_regulation_periods(tbs.id)
        self.assertEqual(len(periods), 1)
        rp = periods[0]
        self.assertEqual(len(rp.period_products), 2)

        pp = [p.tbs_product_level for p in rp.period_products]
        self.assertTrue(product_level1 in pp)
        self.assertFalse(product_level2 in pp)
        self.assertTrue(product_level3 in pp)

        trpp = self.sa_session.query(WeTbsRegulationPeriodProduct)\
            .filter(and_(WeTbsRegulationPeriodProduct.tbs_regulation_period == rp,
                         WeTbsRegulationPeriodProduct.tbs_product_level == product_level1)).first()
        self.assertEqual(trpp.fee, Decimal('-12.34000'))

    def test_regulation_period_update(self):
        tbs = self._create_tbs(self._operator_account.id)
        product_level1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level2, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level3, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        pc = WeProductController(self.sa_session, account_id=self._operator_account.id)
        rp = pc.save_or_update_regulation_period(None, tbs.id, 'My First Period, eww', today().year, 1, 1, [{
            'id': product_level1.id,
            'fee': Decimal('25.3')
        }, {
            'id': product_level2.id,
            'fee': Decimal('12.2')
        }])

        self.click_iconbar('icon-we-tbs-price-sheet-manager', 'icon-we-tbs-manager')

        self.filter_cq(panel_name='we-tbs-price-sheet-manager', filters=[('Tbs', 'Contains', tbs.name)])
        self.wait_for_loading()

        self.click_cq(panel_name='we-tbs-price-sheet-manager', row_index=0, col_name='regulation_period')
        self.wait_for_loading()

        self.click_fieldset(panel_name='we-tbs-regulation-period-details', title='Local categories')
        # add another category
        self.fill_form(panel_name='we-tbs-regulation-period-details', values={
            'tbs_product_levels': ('fancy-select', [
                '%s - %s' % (product_level3.label, product_level3.description)
            ])
        })
        self.wait_for_loading()

        self.fill_form(panel_name='we-tbs-regulation-period-details', values={
            'fee_%d' % product_level3.id: '9.876',
        })

        self.click_button(panel_name='we-tbs-regulation-period-details', text='Save')
        self.wait_for_loading()

        self.sa_session.expire(rp)
        self.assertEqual(len(rp.period_products), 3)

        pp = [p.tbs_product_level for p in rp.period_products]
        self.assertTrue(product_level1 in pp)
        self.assertTrue(product_level2 in pp)
        self.assertTrue(product_level3 in pp)

        # delete the added category
        self.click_cq(panel_name='we-tbs-price-sheet-manager', row_index=0, col_name='regulation_period')
        self.wait_for_loading()

        self.click_fieldset(panel_name='we-tbs-regulation-period-details', title='Local categories')
        # deselect from fancy select
        self._deselect_category('we-tbs-regulation-period-details', 'tbs_product_levels',
                                '%s - %s' % (product_level3.label, product_level3.description))
        self.wait_for_loading()

        self.click_button(panel_name='we-tbs-regulation-period-details', text='Save')
        self.wait_for_loading()

        self.sa_session.expire(rp)
        self.assertEqual(len(rp.period_products), 2)

        pp = [p.tbs_product_level for p in rp.period_products]
        self.assertTrue(product_level1 in pp)
        self.assertTrue(product_level2 in pp)

    def test_hqpp_new_regulation_period(self):
        cn8 = self.sa_session.query(WeCN8).first()

        controller = WeProductController(self.sa_session, account_id=self._operator_account.id)

        tbs = self._create_tbs(self._operator_account.id)
        product_level1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='1.1.1')
        product_level2, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level3, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        rp = controller.save_or_update_regulation_period(None, tbs.id, 'Test RP', 2015, 1, 1, [{
            'id': product_level1.id,
            'fee': Decimal('20.12')
        },{
            'id': product_level2.id,
            'fee': Decimal('33.33')
        },{
            'id': product_level3.id,
            'fee': Decimal('12.45')
        }])

        rpl1 = rp.period_products[0]
        rpl2 = rp.period_products[1]
        rpl3 = rp.period_products[2]

        # add a few producers
        products = self._add_member_products(tbs, [rpl1, rpl2, rpl3], self._operator_account.id)

        # make a new period
        product_level4, tbs = self.create_tbs_product_level(self._operator_account.id, tbs, product_label='1.1.1', description='Different than the previous')
        product_level5, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        rp2 = controller.save_or_update_regulation_period(None, tbs.id, 'Test RP 1', 2015, 6, 1, [{
            'id': product_level4.id,
            'fee': Decimal('20.12')
        },{
            'id': product_level5.id,
            'fee': Decimal('33.33')
        },{
            'id': product_level3.id,
            'fee': Decimal('12.45')
        }])

        set_date(date(2015, 6, 1))

        controller.compare_regulation_period_with_previous(rp2.id, False)

        hqpp = products[0].product.hqpp
        account = hqpp.default_group.accounts[0]

        self.login(account.name, 'abcd123456')
        self.wait_for_loading()

        self.click_iconbar('icon-notifications')
        self.wait_for_loading()

        self.click_cq(panel_name='notifications_manager', row_index=0, col_name='callback')
        self.wait_for_loading()

        self.click_button(panel_name='we-hqpp-new-regulation-period-wizard', text=u'Next »')
        self.wait_for_loading()

        self.fill_form(panel_name='we-hqpp-new-regulation-period-wizard', values={
            'tbs_product_level_id': ('select', 'value=all_categories+%d' % product_level5.id)
        })

        self.click_button(panel_name='we-hqpp-new-regulation-period-wizard', text=u'Next »')
        self.wait_for_loading()

        self.fill_form(panel_name='we-hqpp-new-regulation-period-wizard', form_name='hqpp_product_form_%d' % products[1].product.id, values={
            'tbs_product_level_id': ('select', 'value=all_categories+%d' % product_level4.id)
        })

        self.click_button(panel_name='we-hqpp-new-regulation-period-wizard', text=u'Next »')
        self.wait_for_loading()

        self.click_button(panel_name='we-hqpp-new-regulation-period-wizard', text=u'Finish')
        self.wait_for_loading()

        products = controller.get_producer_regulation_period_products(hqpp, rp2).all()
        self.assertEqual(len(products), 3)
        for p in products:
            self.assertTrue(p.tbs_regulation_period_product.tbs_product_level in [product_level3, product_level4, product_level5])

    def test_regulation_period_archive(self):
        tbs = self._create_tbs(self._operator_account.id)
        product_level1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level2, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        product_level3, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)

        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        pc = WeProductController(self.sa_session, account_id=self._operator_account.id)
        rp = pc.save_or_update_regulation_period(None, tbs.id, 'My First Period, eww', today().year, 1, 1, [{
            'id': product_level1.id,
            'fee': Decimal('25.3')
        }, {
            'id': product_level2.id,
            'fee': Decimal('12.2')
        }])

        self.click_iconbar('icon-we-tbs-price-sheet-manager', 'icon-we-tbs-manager')

        self.filter_cq(panel_name='we-tbs-price-sheet-manager', filters=[('Tbs', 'Contains', tbs.name)])
        self.wait_for_loading()

        self.click_cq(panel_name='we-tbs-price-sheet-manager', row_index=0, col_name='regulation_period')
        self.wait_for_loading()

        self.click_button(panel_name='we-tbs-regulation-period-details', text='Archive')
        self.wait_for_loading()

        self.sa_session.expire(rp)
        self.assertEqual(rp.archived, 1)

        self.assert_cq_empty(panel_name='we-tbs-price-sheet-manager')

    def test_archived_regulation_period_not_shown(self):
        # create member with lpp at tbs
        set_date(date(2015, 2, 1))
        member, lpp, pl, tbs = self.create_lpp()
        pl1, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        pl2, tbs = self.create_tbs_product_level(self._operator_account.id, tbs)
        rp1 = self.create_tbs_regulation_period(tbs.id, self._uniquestring('RP'), 2015, 1, [{
            'id': pl1.id,
            'fee': Decimal('12.345')
        },{
            'id': pl2.id,
            'fee': Decimal('1.002')
        }])

        self.login(self._operator_account.name, 'test_password')
        self.wait_for_loading()

        # set RP to archived
        self.click_iconbar('icon-we-tbs-price-sheet-manager', 'icon-we-tbs-manager')

        self.filter_cq(panel_name='we-tbs-price-sheet-manager', filters=[('Tbs', 'Contains', tbs.name)])
        self.wait_for_loading()

        self.click_cq(panel_name='we-tbs-price-sheet-manager', row_index=0, col_name='regulation_period')
        self.wait_for_loading()

        self.click_button(panel_name='we-tbs-regulation-period-details', text='Archive')
        self.wait_for_loading()

        # open hqpp product details and check that RP is not shown
        self.click_iconbar('icon-we-hqpp-product-manager', 'icon-we-member-manager')
        self.wait_for_loading()

        self.click_menu(panel_name='we_hqpp_product_manager', menu_index=0, text='Add new product')

        cn8_code = self.sa_session.query(WeCN8).first()

        self.fill_form(panel_name='we_hqpp_product_panel', values={'sku': 'UC123456',
                                                                   'hqpp_id': ('select', member.name),
                                                                   'product_name': 'test product',
                                                                   'weight_per_unit': Decimal('2.123'),
                                                                   'cn8_codes': ('fancy-select', ["%s - %s" % (cn8_code.code, cn8_code.description)])})

        self.assertRaises(NoSuchElementException, self.fill_form, panel_name='we_hqpp_product_panel', rowcontrol_row_index=0,
                       values={'tbs_product_level_id': ('select', "%s - %s" % (pl1.label, pl1.description))})

    def _assert_failures_table(self, table_name, number_of_lines):
        table_el = 'table#%s tr.failures-line' % table_name

        row_i = len(self._driver.find_elements_by_css_selector(table_el))
        self.assertEqual(row_i, number_of_lines)

    def _deselect_category(self, panel_name, container_name, category):
        css = self.wait_for_panel_or_form(panel_name)
        container = css + 'div[name=%s]' % container_name
        right_select = container + " select[id$='rightselect']"

        s = self._driver.find_element_by_css_selector(right_select)

        select = Select(s)

        select.select_by_visible_text(category)

        button = self.find_element_by_css_contains(container + ' button', 'Deselect')
        button.click()
