'''
Created on Jan 14, 2015

@author: rado
'''
from we.test.unit.we_unittest import WeUnitTestCase
import os
from we.product.importers import CN8CsvImporter, CN8XlsxImporter
from we.product.models import WeCN8
from django.conf import settings
from basesoft.web.contrib.file.controllers import UploadFileController
from django.core.files.uploadedfile import SimpleUploadedFile
from we.product.controllers import WeProductController

class TestCase(WeUnitTestCase):
    def setUp(self):
        self.connect_db()

    def test_cn8_importer(self):
        # test CSV import
        csv_file_path = os.path.join(os.path.dirname(__file__), os.pardir, 'files', 'test_cn8.csv')
        cn8s = [88888888, 99999999, 77777777, 66666666]
        cn8_description = ['Vacuum cleaners csv', 'CPU, motherboard csv', 'Test n.e.s csv', 'Test no UNU']
        weee_cat = ['EEE-1.01.01', 'EEE-1.02.01', 'EEE-1.03.01', 'EEE-1.03.01']
        unu = ['0444', '0555', '0666', '']
        unu_descripiton = ['Description1', 'Description2', 'Description3', '']
        importer = CN8CsvImporter(self.sa_session)
        importer.import_file(csv_file_path, None)

        # assert codes are inserted properly
        for i in xrange(len(cn8s)):
            cn = self.sa_session.query(WeCN8).filter(WeCN8.code == cn8s[i]).first()
            self.assertEqual(cn.description, cn8_description[i])
            self.assertEqual(cn.weee_product_level.label, weee_cat[i])
            if i == 3:
                self.assertEqual(cn.unu_code, None)
                continue
            self.assertEqual(cn.unu_code.code, unu[i])
            self.assertEqual(cn.unu_code.description, unu_descripiton[i])

        # test XLSX import, replace codes with new description (update)
        xlsx_file_path = os.path.join(os.path.dirname(__file__), os.pardir, 'files', 'test_cn8.xlsx')
        cn8s = [88888888, 99999999, 77777777]
        cn8_description = ['Vacuum cleaners xlsx', 'CPU, motherboard xlsx', 'Test n.e.s xlsx']
        weee_cat = ['EEE-1.01.01', 'EEE-1.02.01', 'EEE-1.03.01']
        unu = ['0444', '0555', '0666']
        unu_descripiton = ['Description1', 'Description2', 'Description3']
        importer = CN8XlsxImporter(self.sa_session)
        importer.import_file(xlsx_file_path, None)

        # assert description and clean db
        for i in xrange(len(cn8s)):
            cn = self.sa_session.query(WeCN8).filter(WeCN8.code == cn8s[i]).first()
            self.assertEqual(cn.description, cn8_description[i])
            self.assertEqual(cn.weee_product_level.label, weee_cat[i])
            self.assertEqual(cn.unu_code.code, unu[i])
            self.assertEqual(cn.unu_code.description, unu_descripiton[i])
            self.sa_session.delete(cn)
        self.sa_session.flush()

    def test_import_cn8_codes(self):
        # test controller for importing cn8 codes
        operator = self._create_operator_account()
        c = WeProductController(self.sa_session, operator.id)
        content = "%s\n%s\n%s" \
                %  ("'CN8,CN8 description,WEEE category,UNU code,UNU description'",
                    "22222222,'Globes, printed (excl. relief globes)','EEE-1.02.01','0555','Description2'",
                    "11111111,'Electric blankets of all types of textile materials','EEE-1.03.01','0666','Description3'")

        _file = {'filedata': SimpleUploadedFile('test.csv', content)}

        uc = UploadFileController(self.sa_session, operator.id)
        tmp_file = uc.save_temp_files(_file)[0]

        self.assertEqual(tmp_file.file_name, 'test.csv')
        # lets see if the file is in the right destination
        self.assertTrue(os.path.exists(os.path.join(settings.TMP_FILE_REPOSITORY,
                                                         tmp_file.file_hash)))
        c.import_cn8_codes(tmp_file, CN8CsvImporter(self.sa_session))
        # try to get the newly imported code. If code is not in db query would error
        cn = self.sa_session.query(WeCN8).filter(WeCN8.code == 11111111).one()
        self.assertEqual(cn.description, 'Electric blankets of all types of textile materials')
        self.assertEqual(cn.unu_code.code, '0666')
        self.assertEqual(cn.weee_product_level.label, 'EEE-1.03.01')

    def test_save_or_update_cn8_code(self):
        state = {
            'cn8_code': 88888888,
            'cn8_description': 'random test code'
        }

        operator = self._create_operator_account()
        c = WeProductController(self.sa_session, account_id = operator.id)

        code = c.save_or_update_cn8_code(state)
        self.assertEqual(code.code, state['cn8_code'])

        state1 = {
            'cn8_code': 88888888,
            'cn8_description': 'random test code UPDATE'
        }
        update = c.save_or_update_cn8_code(state1)
        self.assertEqual(update.description, state1['cn8_description'])
