'''
Created on Dec 17, 2014

@author: marten
'''
from we.core.controllers import AbstractWeController
from we.test.unit.we_unittest import WeUnitTestCase

from we.tbs.controllers import WeTbsController
from we.tbs.models import WeTbsLicense
from basesoft.web.contrib.contact.models import Person
from basesoft.web.core.util.controllers import LicenseConfigController

class TestCase(WeUnitTestCase):

    def setUp(self):
        self.connect_db()

        self._operator_account = self._create_operator_account()

    def test_save_and_update_tbs(self):

        tc = WeTbsController(self.sa_session, account_id=self._operator_account.id)

        tbs_name = self._uniquestring('TBS')[:20]
        state = {
            'company': {
                'name': tbs_name,
                'website': 'http://tbs.com',
                'vat_no': 'BE0893027827',
                'notes': '= hello ='
            },
            'company_bank_account': {
                'is_default': True,
                'bank_account': {
                    'iban': "IL620108000000099999999",
                    'bic': "DEUTDEFF",
                    'number': "324234234",
                }
            },
            'company_address': {
                'is_invoice': True,
                'is_delivery': True,
                'address': {
                    'street': 'TBS Street',
                    'city': 'Amsterdam',
                    'postcode': '1000AA',
                    'country': 1,
                    'state': 'NH'
                }
            },
            'contact_person': {
                'first_name': 'TBS First Name',
                'last_name': 'TBS Last Name',
                'email': 'tbs-test@mail-test.basesoft.com',
                'preferred_locale': 55,
                'gender': Person.FEMALE,
                'phone': '3459764356',
                'mobile_phone': '3459764356'
            }
        }

        tbs = tc.save_or_update_tbs(None, state)

        self.assertTrue(isinstance(tbs, WeTbsLicense))

        state = tc.load_tbs(tbs.id)

        state['contact_person']['last_name'] = 'UPDATED last name'
        tbs = tc.save_or_update_tbs(tbs.id, state)
        self.assertEqual(tbs.company.contact_person.last_name, 'UPDATED last name')
        self.assertEqual(tbs.company.notes, '= hello =')

    def test_tbs_save_settings(self):
        tbs = self._create_tbs(self._operator_account.id)
        tc = WeTbsController(self.sa_session, account_id=self._operator_account.id)

        state = tc.load_tbs(tbs.id)
        self.assertEqual(state['configs']['we.tbs.declaration.period'], WeTbsLicense.DECLARATION_PERIOD_MONTHLY)

        state['configs']['we.tbs.declaration.period'] = WeTbsLicense.DECLARATION_PERIOD_YEARLY
        state['dbID'] = tbs.id
        tc.save_license_from_state(state)

        lcc = LicenseConfigController(self.sa_session, scope=tbs)
        self.assertEqual(lcc.get('we.tbs.declaration.period'), WeTbsLicense.DECLARATION_PERIOD_YEARLY)

    def test_get_tbs_licenses(self):
        core_c = AbstractWeController(sa_session=self.sa_session, account_id=self._operator_account.id)

        # create tbs and assert we can get it as operator
        tbs = self._create_tbs(self._operator_account.id)

        tbs = core_c.get_tbs_licenses(tbs.id)
        self.assertEqual(1, len(tbs))

        # create 3 lpps at 3 tbses
        vats = self.get_vat_numbers()
        member, lpps, tbses_list = self.create_lpps(vats, 3)
        member, member_acc = self._create_member(self._operator_account.id, member.id, create_account=True)

        # instantiate controller with member
        cc = AbstractWeController(self.sa_session, account_id=member_acc.id)

        tbses = cc.get_tbs_licenses()

        # assert member sees 3 tbses
        self.assertEqual(3, len(tbses))