'''
Created on Oct 10, 2014

@author: marten
'''
from datetime import date
from decimal import Decimal

from basesoft.util.virtual_date import today
from basesoft.web.test.unit import iqportal_unittest
from basesoft.web.contrib.license.controllers import LicenseController
from basesoft.web.contrib.contact.models import Person
from we.declaration.controllers import WeDeclarationController
from we.member.models import WeLpp
from we.tbs.controllers import WeTbsController
from we.product.controllers import WeProductController
from we.member.controllers import WeMemberController
from we.product.models import WeCN8, WeHqppRegulationPeriodProduct, WeTbsProductLevel


class WeUnitTestCase(iqportal_unittest.IQPortalTestCase):

    def reset_vat(self):
        self.sa_session.execute("UPDATE tblCompany set vat_no = CONCAT(vat_no, '_test') WHERE SUBSTRING(vat_no, -5) != '_test';")

    def _get_address_data(self):
        return {
            'country': 155,
        }

    def _fill_cn8_codes(self):
        # insert codes
        codes = [(49051000, 'Vacuum cleaners'), (63011000, 'Monitors'), (73211110, 'CPU'), (73211190, 'Toasters'),
                 (73211900, 'Microwaves'), (84041000, 'Fans'), (84021200, 'Drilling'), (84022000, 'Sewing')]
        for code in codes:
            cn8 = self.sa_session.query(WeCN8).filter(WeCN8.code == code[0]).first()
            if cn8 is None:
                cn8 = WeCN8()
                cn8.code = code[0]
                cn8.description = code[1]
            # clear if the codes already exist
            cn8.unu_code_id = None
            cn8.weee_product_level_id = None
            self.sa_session.add(cn8)
        self.sa_session.flush()


    def _get_operator_license_state(self):
        return {
            'license': {
                'name': u'test_we_operator_license',
                'expiration_date': None,
                'is_default': True,
                'polymorphic_type': 'WeOperatorLicense',
                },
            'domain': {'name': 'WEEE Europe'},
            'contact_person': {
                'first_name': u'Marten',
                'last_name': u'Koedam',
                'gender': Person.MALE,
                'email': u'marten@basesoft.com',
                'position': u'developer',
                'department': u'development',
                'phone': '+31206847087',
                'birth_date': '1981-10-30',
                'address_data': self._get_address_data()
                },
            'company': {
                'name': self._uniquestring('WECompany'),
                'vat_no': 'NL810449493B01',
                'website': u'http://www.basesoft.com',
                },
            'company_address': {
                'address': self._get_address_data(),
                'is_invoice': True,
                'is_delivery': False
                },
            'company_bank_account': {
                'bank_account': {
                    'number': self._uniquestring('99'),
                    'iban': self._uniquestring('NL'),
                    'bic':'BBBBNLNH'},
                'is_default': True
                },
            'group': {'name': u'admins'},
            'permissions': [],
            'usage_options': []
        }

    def _get_tbs_state(self, company_prefix):
        return {
            'company': {
                'name': self._uniquestring(company_prefix),
                'website': 'http://tbs.com',
                'vat_no': 'BE0893027827'
            },
            'company_bank_account': {
                'is_default': True,
                'bank_account': {
                    'iban': "IL620108000000099999999",
                    'bic': "DEUTDEFF",
                    'number': "324234234",
                }
            },
            'company_address': {
                'is_invoice': True,
                'is_delivery': True,
                'address': self._get_address_data(),
            },
            'contact_person': {
                'first_name': 'TBS First Name',
                'last_name': 'TBS Last Name',
                'email': 'tbs-test@mail-test.basesoft.com',
                'preferred_locale': 55,
                'gender': Person.FEMALE,
                'phone': '3459764356',
                'mobile_phone': '3459764356'
            }
        }

    def _get_member_state(self, company_prefix='comp'):
        return {
            'license': {
                'name': self._uniquestring(company_prefix),
                'expiration_date': None,
                'is_default': True,
                'polymorphic_type': 'WeHqppLicense',
                },
            'domain': {'name': 'WEEE Europe'},
            'contact_person_data': {
                'first_name': u'Marten',
                'last_name': u'Koedam',
                'gender': Person.MALE,
                'email': u'marten@basesoft.com',
                'position': u'developer',
                'department': u'development',
                'phone': '+31206847087',
                'birth_date': '1981-10-30',
                'address_data': self._get_address_data()
                },
            'company': {
                'name': self._uniquestring(company_prefix),
                'vat_no': 'NL810449493B01',
                'website': u'http://www.basesoft.com',
                },
            'address_data': self._get_address_data(),
            'bank_data': {
                'iban': "IL620108000000099999999",
                'bic': "DEUTDEFF",
                'number': "324234234",
            },
            'group': {'name': u'admins'},
            'permissions': [],
            'usage_options': []
        }

    def get_lpp_state(self, member_id, tbs_id, vat_no=None):
        return {
            'lpp': {
                'tbses': [{
                    'tbs_id': tbs_id,
                    'lpp_relation_id': 123,
                    'invoice_relation_id': 123,
                    'lpp_id': None,
                    'use_as_ar': False
                }],
                'member_id': member_id
            },
            'address_data': {'city': u'Boston', 'state': u'Indiana',
                             'street': u'West street', 'country_iso_3166_a2': u'AO',
                             'postcode': u'1132WD', 'country': 7L, 'country_name': u'Angola',
                             'street_2': None, 'country_iso_3166_a3': u'AGO'},
            'contact_person_data': {
                             'first_name': u'John', 'last_name': u'Doe', 'middle_name': u'van', 'polymorphic_type': u'Person',
                             'skype_name': u'BaronJohn', 'title': u'Baron', 'fax': u'123323456', 'phone': u'123456678',
                             'mobile_phone': u'003132435655', 'gender': u'male', 'birth_date': date(1978, 12, 12), 'position': u'Manager',
                             'department': u'IT', 'email': u'doe@john.com', 'preferred_locale': 1
            },
            'bank_data': {
                             'bank_name': u'BankCorp', 'beneficiary': u'What is this?',
                             'number': u'3838383838', 'bic': u'BIC123457',
                             'note': u'Its a note', 'iban': u'AO22BC390594389'
            },
            'website': u'http://wwww.basesoft.com/',
            'name': self._uniquestring('LPP'),
            'vat_no': u'RO1630615123457' if vat_no is None else vat_no,
        }

    def get_lpp_to_tbs_state(self, lpp, tbses, is_member=False):
        """
        is_member = True - only when this is the time to save member as LPP
        :param lpp: WeLpp or WeHqppLicense object
        :param tbses: List of WeTbsLicense objects
        :param is_member: Boolean
        :return: Dictionary
        """
        state = {}
        state['tbs_links'] = []

        # update the actual lpp and add new records for the rest of the TBSes
        count = 0
        for tbs in tbses:
            state['tbs_links'].append({
                                    'lpp_id': lpp.id if count == 0 and is_member is False else None,
                                    'tbs_id': tbs.id,
                                    'lpp_company_id': lpp.company.id,
                                    'ar_company_id': None,
                                    'invoice_company_id': None
                                })
            count += 1
        return state

    def get_third_party_company_state(self, vat_no=None):
        return {
            'address_data': {'city': u'Los Angeles', 'state': u'California',
                             'street': u'West street', 'country_iso_3166_a2': u'AO',
                             'postcode': u'1132WD', 'country': 7L, 'country_name': u'Angola',
                             'street_2': None, 'country_iso_3166_a3': u'AGO'},
            'contact_person_data': {
                             'first_name': u'Peter', 'last_name': u'Johnson', 'middle_name': u'van', 'polymorphic_type': u'Person',
                             'skype_name': u'BaronJohn', 'title': u'Baron', 'fax': u'123323456', 'phone': u'123456678',
                             'mobile_phone': u'003132435655', 'gender': u'male', 'birth_date': date(1978, 12, 12), 'position': u'Manager',
                             'department': u'IT', 'email': u'doe@john.com', 'preferred_locale': 1
            },
            'bank_data': {
                             'bank_name': u'GoldmanSucks', 'beneficiary': u'What is this?',
                             'number': u'3838383838', 'bic': u'BIC123457',
                             'note': u'Its a note', 'iban': u'AO22BC390594389'
            },
            'website': u'http://wwww.thirdparty.com/',
            'name': self._uniquestring('Company'),
            'vat_no': u'ATU12345675' if vat_no is None else vat_no,
            'member_id': None
        }

    def get_vat_numbers(self):
        return ['AR00000000000', 'RO1630615123457', 'ATU12345675', 'ATU12345620']

    def _create_sysadmin_account(self):

        # sysadmin
        sysadmin_account = self._create_active_account()
        sysadmin_group = sysadmin_account.groups[0].group
        self._attach_permissions_to_group(sysadmin_group,
            'view_dashboard',
            'view_domain', 'view_license', 'view_all_domains', 'view_group', 'create_domain', 'create_license',
            'distribute_group_permissions', 'distribute_license_permissions', 'manage_roles',
            'scheduler_manager',
            'we_operator_license',
        )

        return sysadmin_account

    def _create_operator_account(self):
        sysadmin_account = self._create_sysadmin_account()

        # operator license
        lc = LicenseController(self.sa_session, account_id=sysadmin_account.id)
        operator_license = lc.save_license_from_state(self._get_operator_license_state())

        # operator user
        operator_account = self._create_active_account(license=operator_license)
        operator_group = operator_account.groups[0].group
        self._attach_permissions_from_role(operator_group, 'WE Operator')

        return operator_account

    def _create_tbs(self, operator_account_id=None):

        if operator_account_id is None:
            operator_account_id = self._create_operator_account().id

        tc = WeTbsController(self.sa_session, account_id=operator_account_id)
        state = self._get_tbs_state('TBS')

        return tc.save_or_update_tbs(None, state)

    def _create_tbs_account(self, tbs):
        account = self._create_active_account(tbs)
        lc = LicenseController(self.sa_session, account_id=self._create_operator_account().id)
        lc.grant_from_role('WE TBS', tbs, account.default_group, link_role=True)

        return account

    def create_tbs_product_level(self, operator_account_id=None, tbs=None, product_level_id=None, parent_level_id=None, product_label=None,
                                 start_date=None, end_date=None, invoice_basis=None, description='Test category'):

        if operator_account_id is None:
            operator_account_id = self._create_operator_account().id

        wpc = WeProductController(self.sa_session, account_id=operator_account_id)
        if tbs is None:
            tbs = self._create_tbs()

        _id = None
        if product_level_id is not None:
            _id = product_level_id

        parent_id = None
        if parent_level_id is not None:
            parent_id = parent_level_id

        if product_label is None:
            product_label = self._uniquestring('Level')[:15]

        if start_date is None:
            start_date = date(2015, 1, 1)

        return wpc.save_or_update_tbs_product_level(_id, product_label, description, tbs.id, parent_id,
                                                    invoice_basis), tbs

    def _create_member(self, operator_account_id=None, member_id=None, create_account=False):

        if operator_account_id is None:
            operator_account_id = self._create_operator_account().id

        c = WeMemberController(self.sa_session, account_id=operator_account_id)
        member = c.save_or_update_member(_id=member_id, state=self._get_member_state('member'))

        if create_account is True:
            account = self._create_active_account(license=member, group=member.groups[0])
            return member, account

        return member

    def create_lpp(self, member_account=False, member=None, tbs=None, product_level=None):

        operator_account_id = None
        try:
            operator_account_id = self._operator_account.id
        except AttributeError:
            pass
        try:
            operator_account_id = self.operator_account.id
        except AttributeError:
            pass

        if operator_account_id is None:
            operator_account_id = self._create_operator_account().id

        if tbs is None:
            tbs = self._create_tbs(operator_account_id)

        account_data = None
        if member_account:
            account_data = {
                'person': {
                    'is_same_person_as': False,
                    'last_name': 'Member Contact Last Name',
                    'first_name': 'Member Contact First Name',
                    'email': 'test-member@mail-test.basesoft.com',
                    'preferred_locale': '1',
                    'gender': 'male',
                    'phone': '234234235',
                    'mobile_phone': '123412345',
                },
                'password': {
                    'send_link': False,
                    'new_password': 'abcd123456',
                    'new_password_verify': 'abcd123456',
                },
                'account_details': {
                    'account_name': self._uniquestring('a')
                }
            }

        c = WeMemberController(self.sa_session, account_id=operator_account_id)
        if member is None:
            master_data = self._get_member_state('a')
            member = c.register_member(master_data, account_data)

        # add LPP
        lpp_state = self.get_lpp_state(member.id, tbs.id)
        lpp = c.save_or_update_company_details(None, lpp_state)

        # add LPP to TBS
        state = {
            'tbs_links': [{
                'lpp_id': lpp.id,
                'tbs_id': tbs.id,
                'lpp_company_id': lpp.company.id,
                'ar_company_id': None,
                'invoice_company_id': None
            }]
        }
        c.save_companies_linked_to_tbs(member.id, state)

        # we need a product level as well
        if product_level is None:
            product_level, tbs = self.create_tbs_product_level(operator_account_id, tbs)

        return member, lpp, product_level, tbs

    def _add_member_products(self, tbs, period_products, operator_account_id):
        if type(period_products) != list:
            period_products = [period_products]

        member, lpp, tbs_product_level, tbs = self.create_lpp(member_account=True, tbs=tbs, product_level=period_products[0].tbs_product_level)

        cn8 = self.sa_session.query(WeCN8).first()
        rv = []

        controller = WeProductController(self.sa_session, account_id=operator_account_id)

        for p in period_products:

            state = self.get_product_state(member.id, cn8.code, [p.tbs_product_level.id], sku='MYSKU%d' % p.id)
            product = controller.save_or_update_hqpp_product(state['product_id'], state, p.tbs_regulation_period)
            rpp = self.sa_session.query(WeHqppRegulationPeriodProduct).filter(WeHqppRegulationPeriodProduct.product==product).first()
            rv.append(rpp)

        return rv

    def create_lpps(self, vats, lpp_count=1, same_tbs=False):
        """
        Create LPPs at different TBSes for one member
        :return:
        """
        operator_account_id = None
        try:
            operator_account_id =self._operator_account.id
        except AttributeError:
            pass
        try:
            operator_account_id =self.operator_account.id
        except AttributeError:
            pass

        if operator_account_id is None:
            operator_account_id = self._create_operator_account().id

        c = WeMemberController(self.sa_session, account_id=operator_account_id)
        master_data = self._get_member_state('a')
        member = c.register_member(master_data, None)

        tbses = []
        if same_tbs is True:
            tbs = self._create_tbs(operator_account_id)
            tbses.append(tbs)
        for i in xrange(0, lpp_count):
            vat_no = vats[i]
            if same_tbs is False:
                tbs = self._create_tbs(operator_account_id)
                tbses.append(tbs)

            tbs = tbses[-1]
            lpp_state = self.get_lpp_state(member.id, tbs.id, vat_no)
            lpp = c.save_or_update_company_details(None, lpp_state)
            tbs_links = self.get_lpp_to_tbs_state(lpp, [tbs])
            c.save_companies_linked_to_tbs(member.id, tbs_links)

        return member, member.lpps, tbses

    def add_hqpp_product(self, hqpp_id, product_level_ids, cn8, sku, is_b2b=False, product_id=None, period=None):
        """
        :param hqpp_id: Int
        :param tbs_id: Int
        :param subcategory_id: Int - Local subcategory ID
        :param cn8: Long - CN8 code
        :param sku: String - Needed for creating more than one product per member
        :param is_b2b: Boolean - Add a B2B/B2C split
        :return: WeHqppProduct object
        """
        product_state = self.get_product_state(hqpp_id, cn8, product_level_ids, sku, is_b2b=is_b2b)

        c = WeProductController(sa_session=self.sa_session, account_id=self._operator_account.id)

        return c.save_or_update_hqpp_product(product_id, product_state, declaration_period=period)

    def get_product_state(self, hqpp_id, cn8_code, product_level_ids, sku=None, is_b2b=False):

        def get_tbs(s, pl_id):
            pl = s.query(WeTbsProductLevel).filter(WeTbsProductLevel.id==pl_id).one()
            return pl.tbs

        lines = []
        if type(product_level_ids) is list:
            for _id in product_level_ids:
                vals = {
                    'hqpp_period_product_id': '',
                    'is_b2b': WeHqppRegulationPeriodProduct.B2B_NOT_APPLICABLE,
                    'tbs_product_level_id': {'all_categories': _id},
                    'tbs_id': get_tbs(self.sa_session, _id).id,
                }

                #if there is B2B/B2C split rotate the values
                if is_b2b is True:
                    if len(lines) == 0:
                        vals['is_b2b'] = WeHqppRegulationPeriodProduct.IS_B2B_FALSE
                    else:
                        val = lines[-1]['is_b2b']
                        if val == WeHqppRegulationPeriodProduct.IS_B2B_FALSE:
                            vals['is_b2b'] = WeHqppRegulationPeriodProduct.IS_B2B_TRUE
                        else:
                            vals['is_b2b'] = WeHqppRegulationPeriodProduct.IS_B2B_FALSE
                lines.append(vals)
        else:
            lines.append({
                'hqpp_period_product_id': '',
                'is_b2b': WeHqppRegulationPeriodProduct.B2B_NOT_APPLICABLE,
                'tbs_product_level_id': {'all_categories': product_level_ids},
                'tbs_id': get_tbs(self.sa_session, product_level_ids).id,
            })

        return {
            'product_id': None,
            'hqpp_id': hqpp_id,
            'product_name': self._uniquestring('P_name')[:20],
            'sku': 'UC123456' if sku is None else sku,
            'cn8_codes': [cn8_code],  # single select fancyselect
            'hs': None,
            'unu_id': None,
            'description': 'This is a lpp product',
            'weight_per_unit': Decimal('2.123'),
            'length_per_unit': Decimal('12.000'),
            'height_per_unit': Decimal('12.000'),
            'width_per_unit': Decimal('15.000'),
            'diagonal': Decimal('12.000'),
            'modulation': 'A',
            'sales_price': None,

            'weight_cat1': Decimal('12.000'),
            'weight_cat2': Decimal('12.000'),
            'weight_cat3': Decimal('12.000'),
            'weight_cat4': Decimal('12.000'),
            'weight_documentation': Decimal('12.000'),
            'weight_package': Decimal('12.000'),
            'weight_batteries': Decimal('12.000'),

            'tbs_rowcontrol': lines
        }

    def create_tbs_regulation_period(self, tbs_id, label, start_year, start_month, categories, weight_settings=1):
        c = WeProductController(sa_session=self.sa_session, account_id=self._operator_account.id)
        return c.save_or_update_regulation_period(None, tbs_id, label, start_year, start_month, weight_settings, categories)

    def create_product_sheet_csv_file(self):
        member, lpps, tbses = self.create_lpps(self.get_vat_numbers(), 4)
        tbs = self._create_tbs(self._operator_account.id)
        pl11, tbs = self.create_tbs_product_level(self._operator_account.id, tbses[0], product_label='11010')
        pl12, tbs = self.create_tbs_product_level(self._operator_account.id, tbses[0], product_label='11011')
        pl13, tbs = self.create_tbs_product_level(self._operator_account.id, tbses[0], product_label='11020')
        pl14, tbs = self.create_tbs_product_level(self._operator_account.id, tbses[0], product_label='11030')
        pl15, tbs = self.create_tbs_product_level(self._operator_account.id, tbses[0], product_label='45030')
        pl16, tbs = self.create_tbs_product_level(self._operator_account.id, tbses[0], product_label='25040')

        tbs2 = self._create_tbs(self._operator_account.id)
        pl21, tbs2 = self.create_tbs_product_level(self._operator_account.id, tbses[1], product_label='4.1.1')
        pl22, tbs2 = self.create_tbs_product_level(self._operator_account.id, tbses[1], product_label='3.4')
        pl23, tbs2 = self.create_tbs_product_level(self._operator_account.id, tbses[1], product_label='4.1.2')
        pl24, tbs2 = self.create_tbs_product_level(self._operator_account.id, tbses[1], product_label='4.1.3')
        pl25, tbs2 = self.create_tbs_product_level(self._operator_account.id, tbses[1], product_label='4.3')

        tbs3 = self._create_tbs(self._operator_account.id)
        pl31, tbs3 = self.create_tbs_product_level(self._operator_account.id, tbses[2], product_label='2/C06')

        tbs4 = self._create_tbs(self._operator_account.id)
        pl41, tbs4 = self.create_tbs_product_level(self._operator_account.id, tbses[3], product_label='3.1')
        pl42, tbs4 = self.create_tbs_product_level(self._operator_account.id, tbses[3], product_label='3.2')
        pl43, tbs4 = self.create_tbs_product_level(self._operator_account.id, tbses[3], product_label='4.2')

        cn8_codes = self.sa_session.query(WeCN8).limit(4).all()

        headers1 = ['sku','name','description','is_b2b','cn8','weight_per_unit','length_per_unit','height_per_unit',
                   'width_per_unit','diagonal','weight_cat1','weight_cat2','weight_cat3','weight_cat4','weight_documentation',
                   'weight_batteries','weight_package','tbs-4','tbs-%s' % tbs.id,'tbs-%s' % tbs2.id,'tbs-%s' % tbs3.id,
                   'tbs-%s'%tbs4.id,'tbs-9','tbs-10','tbs-11','tbs-12']

        tbs1_index = 18
        tbs2_index = 19
        tbs3_index = 20
        tbs4_index = 21

        # end user distinction for TBS 1 and 4
        tbs.set_config('we.tbs.require.end.user.distinction', True)
        tbs4.set_config('we.tbs.require.end.user.distinction', True)

        headers2 = ['sku','name','description','is_b2b','cn8','weight_per_unit','length_per_unit','height_per_unit',
                   'width_per_unit','diagonal','weight_cat1','weight_cat2','weight_cat3','weight_cat4','weight_documentation',
                   'weight_batteries','weight_package','garbage','garbage','garbage','garbage', 'garbage','garbage',
                    'garbage','garbage','garbage']
        row1 = ['210-344','SKU1','','B2B',cn8_codes[0].code,'1.32','','999.999','','1000','','','','','','','','','','','','','','','','']
        row2 = ['210-344','SKU1','','B2C',cn8_codes[0].code,'1.32','','999.999','','1000','','','','','','','','','','','','','','','','']
        row3 = ['210-296','SKU3','','',cn8_codes[1].code,'3.837','','','','','','','','','','','','','','','','','','','','']
        row4 = ['210-30','SKU4','','',cn8_codes[2].code,'2.283','','','','','','','','','','','','','','','','','','','','']
        row5 = ['BG2036','SKU5','','',cn8_codes[3].code,'0.109','17.5','5.2','','','','','','','','','','','','','','','','','','']

        row1[tbs1_index] = '11010'  # B2B
        row2[tbs1_index] = '11030'  # B2C
        row1[tbs4_index] = '3.1'  # B2B
        row2[tbs4_index] = '3.2'  # B2C

        row3[tbs2_index] = '4.1.2'
        row4[tbs2_index] = '4.1.3'

        row5[tbs3_index] = '2/C06'


        import csv
        with open('test_product_sheet.csv', 'wb') as f:
            wr = csv.writer(f, dialect=csv.excel, delimiter=',')
            wr.writerow(headers1)
            wr.writerow(headers2)
            wr.writerow(row1)
            wr.writerow(row2)
            wr.writerow(row3)
            wr.writerow(row4)
            wr.writerow(row5)

        # create tbs regulation period
        rp1 = self.create_tbs_regulation_period(tbs.id, self._uniquestring('RP_'), 2015, 1,
                                          [{'id': pl11.id, 'fee': Decimal('2.22')},
                                           {'id': pl12.id, 'fee': Decimal('0.00')},
                                           {'id': pl13.id, 'fee': Decimal('0.08')},
                                           {'id': pl14.id, 'fee': Decimal('0.09')},
                                           {'id': pl15.id, 'fee': Decimal('0.01')},
                                           {'id': pl16.id, 'fee': Decimal('0.03')}])
        rp2 = self.create_tbs_regulation_period(tbs2.id, self._uniquestring('RP_'), 2015, 1,
                                          [{'id': pl21.id, 'fee': Decimal('2.22')},
                                           {'id': pl22.id, 'fee': Decimal('3.22')},
                                           {'id': pl23.id, 'fee': Decimal('4.22')},
                                           {'id': pl24.id, 'fee': Decimal('5.22')},
                                           {'id': pl25.id, 'fee': Decimal('6.22')}])
        rp3 = self.create_tbs_regulation_period(tbs3.id, self._uniquestring('RP_'), 2015, 1,
                                          [{'id': pl31.id, 'fee': Decimal('0.22')}])
        rp4 = self.create_tbs_regulation_period(tbs4.id, self._uniquestring('RP_'), 2015, 1,
                                          [{'id': pl41.id, 'fee': Decimal('2.22')},
                                           {'id': pl42.id, 'fee': Decimal('2.33')},
                                           {'id': pl43.id, 'fee': Decimal('2.44')}])

        return 'test_product_sheet.csv', member, [tbs, tbs2, tbs3, tbs4], [rp1, rp2, rp3, rp4]
